<?php
namespace {
}



namespace XELOS\Framework\Core\Traits{

	/**
	 * Trait CoreLinkMethods
	 * @package XELOS\Framework\Core\Traits
	 */
	trait CoreLinkMethods
	{



		/**
			 * Wrapper for XF->lib->link substituting modules with instance names etc.
			 * Use param 'dep' to transform a dependency name into the current instance_id
			 *
			 * @param array $args
			 *
			 * @return array|bool
			 */
		private function _link_transform($args){}

		/**
			 * @desc Wrapper for XF->lib->link substituting modules with instance names etc.
			 * @see Link::get_current_link()
			 * @param array $params LinkHelper Params in Array Format
			 * @return array|false ['label'=>'', 'target'=>'', 'class'=>'', 'title'=>'', 'href'=>'', 'full'=>''] Link Resource Array
			 */
		public function get_current_link(array $params){}

		/**
			 *
			 */
		public function get_current_url(){}

		/**
			 * @desc Wrapper for XF->lib->link substituting modules with instance names etc.
			 * @param array Link helper Params in Array Format
			 * @return array|bool Contains array with url, full etc.
			 */
		public function get_link(){}

		/**
			 * @desc Wrapper for XF->lib->get_url substituting modules with instance names etc.
			 * @param array Link helper Params in Array Format
			 * @return string URL
			 * @see XF\Lib\Link::get_url()
			 */
		public function get_url(){}

		/**
			 * @desc Wrapper for XF->lib->link substituting modules with instance names etc.
			 *
			 */
		public function print_current_link(){}

		/**
			 * Wrapper for XF->lib->link substituting modules with instance names etc.
			 *
			 * **Example:**
			 * ```
			 * $this->mod->print_link(array('label'=>$label, 'page'=>$page, 'ajax_modal'=>array('form' => 'noajax')));
			 * $this->mod->print_link(array('label'=>$label, 'page'=>$page, 'JS-FSLoader'=>array('message' => 'loading..','autohide'=>'5000')));
			 *
			 * ```
			 *
			 * @param array $params = [
			 *                      'label'=>$label,
			 *                      'page'=>$page,
			 *                      'cmd'=>$cmd,
			 *                      'class'=>'btn',
			 *                      'target'=>'_new',
			 *                      'title'=>$title,
			 *                      'confirm_text'=>_("Are you sure?"),
			 *                      'JS-FSLoader'=>['message' => 'loading..', 'autohide'=>'5000'],
			 *                      'ajax_modal'=>['form' => 'noajax', 'width'=> 800 ],
			 *                      'ajax_update'=>$domId,
			 *                      'ajax_replace'=>$domId,
			 *                      'xdi' => DocumentIndex,
			 *                      'xui_target' => UIAjaxComponent
			 *                      ]
			 *
			 * @return string Full HTML A Tag
			 */
		public function print_link(array $params){}

	}

	/**
	 * Trait ObjectManager
	 * XELOS Framework
	 * @copyright blueend web:application AG
	 * @author Alex Lung
	 */
	trait ObjectManager
	{

		/**
			 * This property controls if the init method of requested objects is called by this trait or not.
			 * <code>xf_trait::auto_init</code> is set to true by default. If it is set to false, the init method call handling
			 * should be handled manually.
			 *
			 * @var bool
			 */
		protected $auto_init;

		/**
			 * This property effects the object cache. By default it is set to false to enable the object cache for
			 * all requested objects. If this property is set true, the object cache will be disabled.
			 * In factory mode, every object request creates and returns a new object.
			 *
			 * @see xf_trait::object_cache
			 * @var bool
			 */
		protected $factory_mode;

		/**
			 * This is an assoc array and contains objects that will be injected into each requested object. Each containing
			 * object will be injected by the name of the key. E.g. ['mod' => $object] this would inject the property named
			 * mod with the value of $object.
			 *
			 * @var array
			 */
		protected $injection_objects;

		/**
			 * This property contains the path to the folder served as root for all requested
			 * classes. This folder can contains other folder or classes. All requested and
			 * registered classes will be searched in this folder by concating this path with the relative path defined
			 * in the registration of the requested class. If the class is not included it will be done on the fly.
			 *
			 * @var string
			 */
		protected $lib_class_dir;

		/**
			 * An optional possibility to pretend a prefix for all registered classes.
			 * This prefix is only required in the class name of the requested object. The registered
			 * class name should not contains this prefix. E.g. a class called xf_foobar should be registered as foobar.
			 *
			 * @var string
			 */
		protected $lib_class_prefix;

		/**
			 * An optional possibility to pretend a namespace prefix for classes have no namespace yet.
			 * E.g. XELOS\Framework\XF\Lib\
			 * @var string
			 */
		protected $ns_class_prefix;

		/**
			 * Each object created by a success call of <code>__call</code> or __get
			 * will be saved into this property to avoid a multiple creation
			 * of same objects and minimize performance loss. If the multiple creation
			 * of objects is desirable e.g. in factory classes, the caching can be disabled
			 * by setting <code>xf_trait::factory_mode</code> to true.
			 * @see xf_trait::factory_mode
			 * @var array $object_cache Contains all instantiated objects.
			 */
		protected $object_cache;

		/**
			 * The instantiation of a requested object can be processed only if the
			 * class of the object is registered with the class name as key and its information as array
			 * in this property. The element should have at least the class name or the relative path to "class" folder.
			 * E.g. If you want to call <code>my_class</code> the registry must have containing
			 * the following entry:
			 * <code>'my_class' => array('class_name'=>'my_class', 'path' => 'my_classes/my_class.class.php');</code>
			 *
			 * @var array[]
			 */
		protected $registry;



		/**
			 * Magic method.
			 * Returns the requested object. If the object is not cached, it will be instantiated with given arguments.
			 * This method calls <code>xf_trait::get_object</code>.
			 *
			 * @param $class
			 * @param $args
			 * @return mixed
			 */
		public function __call($class, $args){}

		/**
			 * Magic method.
			 * First it checks if the requested property is defined and returns it if null. If not defined of null, it calls
			 * <code>xf_trait::get_object</code> and returns its return value.
			 *
			 * @param $class
			 * @return mixed
			 */
		public function __get($class){}

		/**
			 * Magic method.
			 * This method checks whether the property is defined or injected by <code>__set</code>. If not
			 * injected or defined, it will check the registry for an entry of requested property.
			 *
			 * @param $property
			 * @return bool
			 */
		public function __isset($property){}

		/**
			 * Magic method.
			 * Sets the given value by <code>$name</code>
			 *
			 * @param $name
			 * @param $value
			 */
		public function __set($name, $value){}

		/**
			 * Returns the path to class directory.
			 *
			 * @see xf_trait::lib_class_dir
			 * @see xf_trait::get_lib_class_dir
			 * @return string
			 */
		public function get_lib_class_dir(){}

		/**
			 * Returns the defined prefix for all classes.
			 *
			 * @see xf_trait::lib_class_prefix
			 * @return string
			 */
		public function get_lib_class_prefix(){}

		/**
			 * This method provides the requested objects if the objects is registered and the file / class exists.
			 * If the class is not defined yet, the class file will be included by <code>xf_trait::lib_class_dir</code> + path
			 * defined in registry. If there is no path defined, it will be guess by class name, file name and prefix. This
			 * method also inject all objects contains in <code>xf_trait::injection_objects</code> into the created object.
			 *
			 * @param string     $class
			 * @param null|array $args
			 * @param bool       $call_init
			 *
			 * @return mixed
			 * @throws BadMethodCallException
			 */
		private function get_object($class, $args = NULL, $call_init = true){}

		/**
			 * Returns an array containing all objects were requested.
			 *
			 * @see xf_trait::object_cache
			 * @return array
			 */
		public function get_object_cache(){}

		/**
			 * Add given objects to injection object list that will be inject into
			 * object by magic call. The array should consists of property name as key and object as value.
			 * @param array $objects
			 */
		public function set_injection_objects($objects){}

		/**
			 * Sets the directory where classes are stored.
			 * This folder can contains other folder or classes. All requested and
			 * registered classes will be searched in this folder by concating this path with the relative path defined
			 * in the registration of the requested class. If the class is not included it will be done on the fly.
			 *
			 * @param $lib_class_dir
			 */
		public function set_lib_class_dir($lib_class_dir){}

		/**
			 * Sets the class name prefix.
			 * An optional possibility to pretend a prefix for all registered classes.
			 * This prefix is only required in the class name of the requested object. The registered
			 * class name should not contains this prefix. E.g. a class called xf_foobar should be registered as foobar.
			 *
			 * @param $lib_class_prefix
			 */
		public function set_lib_class_prefix($lib_class_prefix){}

		/**
			 * trait constructor
			 * This method have to be called from constructor of each class that uses this trait.
			 * It sets the defaults and all necessary properties.
			 *
			 * @param bool   $lib_class_dir
			 * @param string $lib_class_prefix e.g. 'xf_'
			 * @param string $ns_prefix e.g. "XELOS\\Framework\\Lib\\"
			 */
		public function xelos_object_manager_init($lib_class_dir, $lib_class_prefix = '', $ns_prefix = ''){}

	}
} 

namespace XELOS\Framework\Module\Model\Traits{

	trait CollectionCacheTrait
	{

		/** @var bool Force all() caching even in CLI Mode */
		private static $forceAllCaching = NULL;

		/** @var \XELOS\Framework\Module\Model\ModelCollection */
		private static $modelCache = NULL;



		/**
			 * Returns all items of the model. Caches the collection at first call
			 * @param array  $queryParams Optional query params, e.g order_by
			 * @return \XELOS\Framework\Module\Model\ModelCollection|$this[]
			 *
			 * @noinspection PhpHierarchyChecksInspection
			 * @noinspection PhpSignatureMismatchDuringInheritanceInspection $query_params are ignored because the cache is only filled once
			 */
		public function all($queryParams = array ( )){}

		/**
			 * Should the fetching of the all() model collection be cached?
			 * @return bool $allCachingEnabled
			 */
		public static function allCachingEnabled(){}

		/**
			 * Clears the model_cache
			 * @return void
			 */
		public function clearCache(){}

		/**
			 * Wraps the find_all_by_id() method, to use the search_all_by_id() method on the cached model collection
			 *
			 * @param array $ids The ids
			 * @param array $queryParams Optional query params, e.g order_by
			 *
			 * @return \XELOS\Framework\Module\Model\ModelCollection|$this[]
			 */
		public function find_all_by_id($ids, $queryParams = array ( )){}

		/**
			 * Wraps the find_by_id() method, to use the search_by_id() method on the cached model collection
			 *
			 * @param int $id Numeric Instance ID
			 * @param array  $queryParams Optional query params, e.g order_by
			 *
			 * @return \XELOS\Framework\Module\Model\Model|$this
			 *
			 * @noinspection PhpHierarchyChecksInspection
			 */
		public function find_by_id($id, $queryParams = array ( )){}

		/**
			 * Get the forceAllCaching state.
			 * @return bool
			 */
		public static function getForceAllCaching(){}

		/**
			 * Force the Caching of all(). Caching disabled in CLI by default.
			 *
			 * @param bool $forceCache
			 * @return void
			 */
		public static function setForceAllCaching($forceCache = true){}

	}

	trait StateMachineTrait
	{

		/**
			 * Has State Machine beein initialized yet (registered event listeners)
			 * @var bool
			 */
		protected $_state_machine_active;

		/**
			 * Array of all fields and their values which have been changed during the last save() call
			 * @var bool
			 */
		protected $_state_machine_field_transitions;

		/**
			 * List of registered transitions which will be checked on field changes
			 * @var array
			 */
		protected $_state_machine_registered_transitions;



		/**
			 * afterSave Event Handler
			 * Process State Machine after Save
			 */
		public function _state_machine_after_save(){}

		/**
			 * beforeSave Event Handler
			 * Identify all properties which will be modified with this call
			 */
		public function _state_machine_before_save(){}

		/**
			 * Checks if the passed value matches the specified rule
			 * @param $value
			 * @param $rule
			 * @return bool
			 */
		private function _state_machine_matches_rule($value, $rule){}

		/**
			 * Register Transition Callback which will be called when field values change according to defined transition
			 * @param string $property_id Property Field which should be monitored
			 * @param mixed $from_value Single start value or array of values
			 * @param mixed $to_value Single target value or array of values
			 * @param $callback Callback function, receives parameters: Model Object, FROM Value, TO Value of field
			 */
		protected function after_transition($property_id, $from_value, $to_value, $callback){}

	}
} 

namespace XELOS\Framework\XF\UI\Form\Traits{

	/**
	 * Trait FormTextboxTrait
	 * @package XELOS\Framework\XF\UI\Form\Traits
	 */
	trait FormTextboxTrait
	{



		/**
			 * @param string $fieldname
			 * @param bool   $default_value
			 * @param string $type
			 *
			 * @return string
			 */
		public function display_textbox_field($fieldname, $default_value = false, $type = 'textbox'){}

	}
} 

