<?php
namespace {
}



namespace XELOS\Modules\ApiCloudstorage{

	/**
	 * Class ApiCloudstorageController
	 *
	 * @package XELOS\Modules\ApiCloudstorage
	 */
	class ApiCloudstorageController extends \XELOS\Framework\Module\Controller implements \XELOS\Framework\Core\Interfaces\ModuleInterface
	{

		/** @var \XELOS\Modules\ApiCloudstorage\Hook\StorageProvider[] */
		private $providers;



		/**
			 * Returns an xui_tree that contains the storage content.
			 *
			 * @param string $provider_name
			 *
			 * @return \XELOS\Framework\XF\UI\Tree
			 */
		public function get_cloud_content_tree($provider_name){}

		/**
			 * Returns a specific storage provider.
			 * If the providers no loaded yet then load all providers
			 * by the load_storage_providers() method.
			 *
			 * @param string $name The name identifier of the provider.
			 *
			 * @return null|\XELOS\Modules\ApiCloudstorage\Hook\StorageProvider
			 */
		public function get_provider($name){}

		/**
			 * Returns all loaded storage provider.
			 * If the providers no loaded yet then load all providers
			 * by the load_storage_providers() method.
			 *
			 * @return \XELOS\Modules\ApiCloudstorage\Hook\StorageProvider[]
			 */
		public function get_providers(){}

		/**
			 * Returns true if the provider exists, otherwise false.
			 *
			 * @param string $name
			 *
			 * @return bool
			 */
		public function has_cloud_service_provider($name){}

		/**
			 * Loads all storage providers by hooks.
			 */
		public function load_storage_providers(){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Hook{

	/**
	 * Class StorageProvider
	 *
	 * @package XELOS\Modules\ApiCloudstorage\Hook
	 */
	abstract class StorageProvider extends \XELOS\Framework\Module\Hook\BaseHook
	{

		/** @var \XELOS\Framework\Module\Controller */
		public $mod;



		/**
			 * Initialize and executes the download of a selected remote file.
			 *
			 * @param string $cloud_source_path
			 * @param string $destination_dir_path
			 *
			 * @return bool
			 */
		public function do_download($cloud_source_path, $destination_dir_path){}

		/**
			 * Returns the account free storage quota in bytes.
			 *
			 * @return int
			 */
		public function get_account_quota_free(){}

		/**
			 * Returns size in bytes of total space of the storage.
			 *
			 * @return int
			 */
		abstract public function get_account_quota_total();

		/**
			 * Returns size in bytes of used space of the storage.
			 *
			 * @return int
			 */
		abstract public function get_account_quota_used();

		/**
			 * Returns the account used storage quota in percent.
			 *
			 * @return int
			 */
		public function get_account_quota_used_percent(){}

		/**
			 * Returns an instance of StorageContent that contains
			 * all files requested by the given path which is provider specific
			 * .
			 *
			 * @param string $path A provider specific remote file path.
			 *
			 * @return \XELOS\Modules\ApiCloudstorage\Lib\StorageContent
			 */
		abstract public function get_content($path);

		/**
			 * Returns the xelos icon class name which presents
			 * the provider storage service.
			 *
			 * @return string
			 */
		abstract public function get_icon_class_name();

		/**
			 * Returns a name identifier of the provider storage service.
			 *
			 * @return string
			 */
		abstract public function get_provider_name();

		/**
			 * Returns the title of the provider storage service.
			 *
			 * @return string
			 */
		abstract public function get_provider_title();

		/**
			 * @return bool
			 */
		public function hideWhenDisconnected(){}

		/**
			 * This method is used to initialize the providers connection by oauth clients.
			 */
		abstract public function init_provider();

		/**
			 * Returns true if the provider is connected.
			 *
			 * @return bool
			 */
		abstract public function is_connected();

		/**
			 * Returns an array which contains the content of the
			 * requested path. This array is used by xui_tree.
			 *
			 * @param string $path A provider specific remote file path.
			 *
			 * @return array
			 *
			 * @deprecated
			 */
		abstract public function on_browse_tree($path = NULL);

		/**
			 * Download the requested remote file and save the content to
			 * the destination path.
			 *
			 * @param string $cloud_source_path
			 * @param string $destination_dir_path
			 */
		abstract protected function on_download($cloud_source_path, $destination_dir_path);

		/**
			 * Executes the provider specific file upload from xelos
			 * to the remote storage space.
			 *
			 * @param string $cloud_path
			 * @param string $fileName
			 * @param resource $fileStream
			 */
		abstract public function on_upload($cloud_path, $fileName, $fileStream);

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Lib{

	/**
	 * Class StorageContent
	 *
	 * @package XELOS\Modules\ApiCloudstorage\Lib
	 */
	class StorageContent
	{

		/** @var array */
		private $files;

		/** @var array */
		private $folder;



		/**
			 * @param $id
			 * @param $name
			 * @param $ext
			 * @param $size
			 * @param $icon
			 * @param $thumb
			 */
		public function add_file($id, $name, $ext, $size, $icon, $thumb){}

		/**
			 * @param $id
			 * @param $name
			 * @param $size
			 * @param $icon
			 * @param $thumb
			 */
		public function add_folder($id, $name, $size, $icon, $thumb){}

		/**
			 * @return array
			 */
		public function get_files(){}

		/**
			 * @return array
			 */
		public function get_folders(){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Selector{

	/**
	 * Class ApiCloudstorageDocumentBrowser
	 *
	 * @package XELOS\Modules\ApiCloudstorage\Selector
	 */
	class ApiCloudstorageDocumentBrowser extends \XELOS\Modules\Selector\Abstracts\AbstractDocumentBrowser
	{

		/** @var \XELOS\Modules\ApiCloudstorage\ApiCloudstorageController */
		protected $mod;



		/**
			 * PersonalWorkspaceDocumentBrowser constructor.
			 *
			 * @param \XELOS\Modules\ApiCloudstorage\ApiCloudstorageController $mod
			 */
		public function __construct(\XELOS\Modules\ApiCloudstorage\ApiCloudstorageController $mod){}

		/**
			 * @inheritdoc
			 */
		public function get_items($id, $offset){}

		/**
			 * Returns a title for this browser.
			 *
			 * @param $item_id
			 *
			 * @return string
			 */
		public function get_title($item_id){}

		/**
			 * @inheritDoc
			 */
		public function handle_selection($item_ids, $form_temp_path){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Hook\ApiCloudstorage{

	/**
	 * Class DropboxStorageProvider
	 */
	class DropboxStorageProvider extends \XELOS\Modules\ApiCloudstorage\Hook\StorageProvider
	{

		/** @var \Kunnu\Dropbox\Models\Account */
		protected $accountInfo;

		/** @var \Kunnu\Dropbox\Dropbox */
		protected $client;

		/** @var array */
		protected $storageInfo;



		/**
			 * @inheritdoc
			 */
		public function get_account_quota_total(){}

		/**
			 * @inheritdoc
			 */
		public function get_account_quota_used(){}

		/**
			 * @inheritdoc
			 */
		public function get_content($path){}

		/**
			 * @inheritdoc
			 */
		public function get_icon_class_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_provider_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_provider_title(){}

		/**
			 * @inheritdoc
			 *
			 * @throws \Exception
			 */
		public function init_provider(){}

		/**
			 * Returns true if this hook is available otherwise false.
			 *
			 * @return bool
			 */
		public function isAvailable(){}

		/**
			 * Returns true if the provider is connected.
			 *
			 * @return bool
			 */
		public function is_connected(){}

		/**
			 * @inheritdoc
			 */
		public function on_browse_tree($path = NULL){}

		/**
			 * @inheritdoc
			 */
		protected function on_download($cloud_source_path, $destination_dir_path){}

		/**
			 * @inheritdoc
			 */
		public function on_upload($cloud_path, $fileName, $fileStream){}

		/**
			 * @param $item_list
			 *
			 * @return array
			 */
		private function sort_item_list($item_list){}

	}

	/**
	 * Class GoogleStorageProvider
	 *
	 * This class represents the cloud storage implementation of Google. The SDK is
	 * placed in the lib/google folder and uses an autoload to load all needed classes.
	 * The authorization is provided by the client class Google_Client. The main
	 * file operations are processed by the Google_service_Drive class. The account
	 * information is provided by the Google_Service_Oauth2 class. All service
	 * classes need the client class to instantiate.
	 *
	 * The token is given after a successful authorization is a json object. This
	 * full json object is needed to restore the client fromt database. Because
	 * the access token is expired after 3600, the json object contains the
	 * refresh token that is important to get a new access token after the current
	 * expires. The refresh token can be only received, if the access type is set to
	 * 'offline'.
	 *
	 * @see https://developers.google.com/drive/api/v3/reference/
	 */
	class GoogleStorageProvider extends \XELOS\Modules\ApiCloudstorage\Hook\StorageProvider
	{

		/** @var \Google_Service_Drive */
		private $service;

		/** @var \Google_Service_Drive_About */
		private $storage_info;



		/**
			 * @inheritdoc
			 */
		public function get_account_quota_total(){}

		/**
			 * @inheritdoc
			 */
		public function get_account_quota_used(){}

		/**
			 * @inheritdoc
			 */
		public function get_content($path){}

		/**
			 * @inheritdoc
			 */
		public function get_icon_class_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_provider_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_provider_title(){}

		/**
			 * @inheritdoc
			 */
		public function init_provider(){}

		/**
			 * Returns true if this hook is available otherwise false.
			 *
			 * @return bool
			 */
		public function isAvailable(){}

		/**
			 * Returns true if the provider is connected.
			 *
			 * @return bool
			 */
		public function is_connected(){}

		/**
			 * @inheritdoc
			 */
		public function on_browse_tree($path = NULL){}

		/**
			 * @inheritdoc
			 */
		protected function on_download($cloud_source_path, $destination_dir_path){}

		/**
			 * @inheritdoc
			 */
		public function on_upload($cloud_path, $fileName, $fileStream){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Hook\Doclink{

	/**
	 * Class UploadDocumentProcessor
	 * @package XELOS\Modules\ApiCloudstorage\Hook\Doclink
	 */
	class UploadDocumentProcessor extends \xm_doclink_processor
	{

		/**
			* @var \XELOS\Modules\ApiCloudstorage\ApiCloudstorageController
			*/
		public $mod;



		/**
		 * Class UploadDocumentProcessor
		 * @package XELOS\Modules\ApiCloudstorage\Hook\Doclink
		 */
		public function ajax($container){}

		/**
			* Returns action if any cloud service is registered in the cloud service manager.
			* If there're no registered cloud provider, this method returns false.
			* 
			* @param mixed $id
			* @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
			* @return bool|array
			*/
		public function get_action($id, $document_index = NULL){}

		/**
			* put your comment there...
			* 
			*/
		public function get_actions(){}

		/**
			* Adds new share action on init.
			* 
			*/
		public function init(){}

		/**
			 * put your comment there...
			 *
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
			 * @param mixed $action_status
			 * @param mixed $direct_show
			 * @param string|bool $keyname
			 *
			 * @return \xelos_global_template
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 */
		public function on_trigger_action(\XELOS\Framework\XF\System\Model\DocumentIndex $document_index, $action_status = false, $direct_show = false, $keyname = false){}

		/**
			 * @param string $provider_keyname
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
			 * @param bool $direct_show
			 *
			 * @return array|\XELOS\Framework\Core\Template|\xelos_global_template
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 */
		public function show_upload($provider_keyname, \XELOS\Framework\XF\System\Model\DocumentIndex $document_index, $direct_show = false){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Hook\Selector{

	/**
	 * Class CloudDocumentBrowser
	 * @package XELOS\Modules\ApiCloudstorage\Hook\Selector
	 */
	class CloudDocumentBrowser implements \XELOS\Modules\Selector\Interfaces\DocumentBrowserHookInterface
	{

		/** @var \XELOS\Modules\ApiCloudstorage\ApiCloudstorageController */
		public $mod;



		/**
			 * @inheritdoc
			 */
		public function get_document_browser(){}

		/**
			 * @inheritdoc
			 */
		public function get_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_thumbnail_url(){}

		/**
			 * Checks whether this browser is consented.
			 *
			 * @return bool
			 */
		public function is_consented(){}

	}
} 

namespace XELOS\Modules\ApiCloudstorage\Hook\Webservice{

	/**
	 * Class DropboxOauthClient
	 *
	 * @package XELOS\Modules\ApiCloudstorage\Hook\Webservice
	 */
	class DropboxOauthClient extends \XELOS\Modules\Webservice\Hook\OAuthClientHook
	{

		 
		protected $description;

		 
		protected $icon_class;

		 
		protected $max_global_connections;

		 
		protected $max_user_connections;

		 
		protected $title;



		/**
			 *
			 * @param array       $connection_fdl_result
			 *
			 * @param string|null $internal_redirect_url
			 *
			 * @return \XELOS\Modules\Webservice\Lib\OAuthClient
			 */
		public function getOAuthClient($connection_fdl_result = NULL, $internal_redirect_url = NULL){}

		/**
			 * Returns true if this hook is available otherwise false.
			 *
			 * @return bool
			 */
		public function isAvailable(){}

	}

	/**
	 * Class GoogleOauthClient
	 *
	 * @package XELOS\Modules\ApiCloudstorage\Hook\Webservice
	 */
	class GoogleOauthClient extends \XELOS\Modules\Webservice\Hook\OAuthClientHook
	{

		 
		protected $description;

		 
		protected $icon_class;

		 
		protected $max_global_connections;

		 
		protected $max_user_connections;

		 
		protected $title;



		/**
			 *
			 * @param array       $connection_fdl_result
			 *
			 * @param string|null $internal_redirect_url
			 *
			 * @return \XELOS\Modules\Webservice\Lib\OAuthClient
			 */
		public function getOAuthClient($connection_fdl_result = NULL, $internal_redirect_url = NULL){}

		/**
			 * Returns true if this hook is available otherwise false.
			 *
			 * @return bool
			 */
		public function isAvailable(){}

	}
} 

