<?php
namespace {
}



namespace XELOS\Modules\Search{

	/**
	 * Class SearchController
	 * This module uses an index to show search results. The index is based on Lucene or mySQL
	 * @package XELOS\Modules\Search
	 */
	class SearchController extends \XELOS\Framework\Module\Controller implements \XELOS\Framework\Core\Interfaces\ModuleInterface
	{

		/** @var bool if set to true, files are indexed */
		public $daemon_mode;

		/** @var \XELOS\Modules\Search\Interfaces\SearchAdapterInterface */
		protected $searchAdapter;

		/** @var string */
		public $search_engine;



		/**
			 * @desc  Add document to the search index (make it available for searching)
			 *
			 * @param string $instance string Instance ID of the module which adds new content
			 * @param int $post_id string UNIQUE Post/Document ID -> Should be created by the module, module should be able to identify
			 *                      documents by this ID
			 * @param string $title string Title of the document
			 * @param string $summary string Summary of the document content
			 * @param int $created_at int Unix-Timestamp of the creation date/time
			 * @param int $user_id int User ID of the document author / owner
		 	 * @param string $index_content string Full content of the document that should be used for indexing
			 * @param int $post_type int Post Type
			 * @param string $thumb Deprecated: Thumbnail Path (Starting X7.1 Thumbnails are being derived from Document Index and do not be passed)
			 * @param array $file_array List of files to add to this document's index can also be document index ids
			 * @param int $group_id Local Group ID as being used in the module (will be converted to Global Group ID)
			 * @param string|bool $locale the locale for the content being indexed. Use false for no specific locale.
			 * @param int $resolve_id The id that matches other language versions of the same document. Defaults to post id
			 *
			 * @deprecated Please use SearchableDocumentModelInterface implementation + enable index_events on the desired document models
			 * @throws Exception
			 */
		public function add_document($instance, $post_id, $title, $summary, $created_at = false, $user_id = false, $index_content = false, $post_type, $thumb = false, $file_array = array ( ), $group_id, $locale = false, $resolve_id = false){}

		/**
			* checks if there is a search term present in DB.
			*
			* @param mixed $q - if set to false, $this->GPvars['q'] is used
			* @param mixed $save - if set to false, $term object will not be saved
			*
			* @return \XELOS\Modules\Search\Model\Term|bool $term - object on success, false on error
			*/
		public function check_for_term($q = false, $save = true){}

		/**
		  * daemon process
		  * takes an entry from queue and calls the add function to add the entry to the index
			 * @deprecated
		  */
		public function daemon_process_queue(){}

		/**
			 * @return \XELOS\Modules\Search\Interfaces\SearchAdapterInterface
			 */
		public function getSearchAdapter(){}

		/**
			 * Retrieves a document search model (depending on the search_engine config setting (sql/lucene))
			 *
			 * @param bool $instance
			 * @param bool $resolve_id
			 * @param bool $post_type
			 * @param int  $document_index_id
			 * @param bool $throw_exception
			 *
			 * @return \XELOS\Modules\Search\Interfaces\SearchAdapterInterfaceLegacy|\XELOS\Modules\Search\Interfaces\SearchDocumentInterface
			 * @throws \Exception
			 */
		public function get_document($instance = false, $resolve_id = false, $post_type = false, $document_index_id = NULL, $throw_exception = false){}

		/**
			* Notify user about Searchagent-Matches
			*  (Function is called by System Notifications Cron)
			*/
		public function get_notifications(){}

		/**
		 * Class SearchController
		 * This module uses an index to show search results. The index is based on Lucene or mySQL
		 * @package XELOS\Modules\Search
		 */
		public function get_page($page_id, $args = array ( )){}

		/**
		  * @desc Returns all posts that are in the passed id list
		  * @param array ID List Array with document ids, e.g. {1=>{post_id=>1, post_type=0, instance_id='test'}, 2=>....}
		  * @return array 1-Dim Array with post_ids
		  */
		public function get_posts_by_idlist($id_list){}

		/**
		  * @desc Returns all posts that match a certain search criteria
		  * @param string Query-String
		  * @param string Instance ID
		  * @param string Post Type
		  * @return array 1-Dim Array with post_ids
		  */
		public function get_posts_by_search($query, $instance_id = false, $post_type, $limit = 200){}

		/**
		  * @inheritdoc
		  */
		public function init(){}

		/**
			 * Reindex all documents from document index (does not clear index)
			 * @deprecated
			 */
		public function rebuild_index(){}

		/**
		  * Add Item to Index Queue
		  *
		  * @param string $instance
		  * @param int $post_id
		  * @param int $post_type
		  * @returns int Q-id
			 * @deprecated
		  */
		public function reindex($instance, $post_id, $post_type, $locale = false){}

		/**
			 * @desc Removes passed document from the search index
			 *
			 * @param     $instance
			 * @param     $resolve_id
			 * @param int $post_type
			 *
			 * @deprecated Please use SearchableDocumentModelInterface implementation + enable index_events on the desired document models
			 *
			 * @throws Exception
			 */
		public function remove_document($instance, $resolve_id, $post_type){}

		/**
			 * Resolves a Document Link and redirects to the document
			 *
			 * @param string|array
			 * @param mixed
			 * @param mixed
			 *
			 * @throws Exception
			 */
		public function resolve_doc_link($instance, $post_id = false, $post_type = false, $group_security_id = false, $search_highlight = false){}

		/**
		  * @desc Update the passed document in the search index
		  * @param string Instance ID of the module which adds new content
		  * @param string UNIQUE Post/Document ID -> Should be created by the module, module should be able to identify documents by this ID
		  * @param string Title of the document
		  * @param string Summary of the document content
		  * @param timestamp Document Last Update or Creation Date
		  * @param int User ID of the document author / owner
		  * @param string Full content of the document that should be used for indexing
		  * @param int Post Type (Default=0)
		  * @param string path to thumbnail
		  * @param array Files to attach
		  * @param int Group ID
		  * @param string The locale of the document to add
		  * @param int The id that matches other language versions of the same document. Defaults to post id
		   *
		   * @deprecated
		  */
		public function update_document($instance, $post_id, $title, $summary, $updated_at = false, $user_id = false, $index_content = false, $post_type, $thumb = false, $file_array = array ( ), $group_id, $locale = false, $resolve_id = false){}

	}

	class SearchIndexContentRecord
	{

		/**
			 * @var string Additional content for indexing
			 */
		protected $indexContent;

		/**
			 * @var bool Marks if this content translation is a machine translated content
			 */
		protected $isAutoTranslated;

		/**
			 * @var string Locale (Language and Culture), e.g. DE_DE
			 */
		protected $locale;

		/**
			 * @var string Summary displayed in Search results, Tags will be stripped - avoid HTML here
			 */
		protected $summary;

		/**
			 * @var string Title of Search Record
			 */
		protected $title;



		/**
			 * SearchIndexRecord is always based on the respective document_index
			 *
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex
			 */
		public function __construct(\XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex){}

		/**
			 * @return string
			 */
		public function getIndexContent(){}

		/**
			 * Returns true if this Content has not been translated by humans (Auto Translated)
			 * @return bool
			 */
		public function getIsAutoTranslated(){}

		/**
			 * @return string
			 */
		public function getLocale(){}

		/**
			 * @return string
			 */
		public function getSummary(){}

		/**
			 * @return string
			 */
		public function getTitle(){}

		/**
			 * @param string $indexContent
			 *
			 * @return SearchIndexRecord
			 */
		public function setIndexContent($indexContent){}

		/**
			 * Set to true if this Content has not been translated by humans
			 * @param bool $isAutoTranslated
			 */
		public function setIsAutoTranslated($isAutoTranslated){}

		/**
			 * @param string $locale
			 *
			 * @return SearchIndexRecord
			 */
		public function setLocale($locale){}

		/**
			 * @param string $summary
			 *
			 * @return SearchIndexRecord
			 */
		public function setSummary($summary){}

		/**
			 * @param string $title
			 *
			 * @return SearchIndexRecord
			 */
		public function setTitle($title){}

	}

	class SearchIndexRecord
	{

		/**
			 * @var string[]|int[] Attachments to be considered for this record. Either file paths or document index ids
			 */
		protected $attachments;

		/**
			 * Contains the default content for this Index Record
			 * @var SearchIndexContentRecord|null
			 */
		private $defaultContent;

		/**
			 * @var \XELOS\Framework\XF\System\Model\DocumentIndex
			 */
		private $documentIndex;

		/**
			 * @var string Additional content for indexing
			 */
		protected $indexContent;

		/**
			 * @var string Locale (Language and Culture), e.g. DE_DE
			 */
		protected $locale;

		/**
			 * @var SearchIndexContentRecord[] Array with additional LanguageRecord objects
			 */
		private $localizedContent;

		/**
			 * @var array PreProcessing Data (used by search preprocessor)
			 */
		protected $preProcessingData;

		/**
			 * @var int Related Primary PostId, e.g. Post ID 2 is the translation of Post ID 1
			 */
		protected $relatedPostId;

		/**
			 * @var bool Set to true to mark this Index Record for deletion
			 */
		protected $removeFromIndex;

		/**
			 * @var string Summary displayed in Search results, Tags will be stripped - avoid HTML here
			 */
		protected $summary;

		/**
			 * @var string Title of Search Record
			 */
		protected $title;



		/**
			 * SearchIndexRecord is always based on the respective document_index
			 *
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex
			 */
		public function __construct(\XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex){}

		/**
			 * Adds an additional language variant of this document
			 * @param $locale
			 * @return SearchIndexContentRecord
			 */
		public function addLocalizedContent($locale, $overwriteExistingContentForLocale = true){}

		/**
			 * @return int[]|string[]
			 */
		public function getAttachments(){}

		/**
			 * Returns an array of localized Content objects containing all available translations for this document
			 * @return SearchIndexContentRecord[]
			 */
		public function getContentRecords(){}

		/**
			 * Returns the initial document creation date as UNIX timestamp
			 * @return int
			 */
		public function getCreatedAt(){}

		/**
			 * @return \XELOS\Framework\XF\System\Model\DocumentIndex
			 */
		public function getDocumentIndex(){}

		/**
			 * @return int
			 */
		public function getGroupSecurityId(){}

		/**
			 * Sets the content which shall be additionally be indexed. By default the title and summary are already indexed.
			 * @return string
			 */
		public function getIndexContent(){}

		/**
			 * @return string
			 */
		public function getLocale(){}

		/**
			 * @return int
			 */
		public function getPostId(){}

		/**
			 * @return int
			 */
		public function getPostType(){}

		/**
			 * Used by Pre-Processing Logic to store / get additional data during indexing
			 * @param string $fieldId
			 * @param $value
			 */
		public function getPreProcessingData($fieldId){}

		/**
			 * @return int
			 */
		public function getRelatedPostId(){}

		/**
			 * Returns true of this index record has been marked for index removal
			 * @return bool
			 */
		public function getRemoveFromIndex(){}

		/**
			 * @return string
			 */
		public function getSummary(){}

		/**
			 * @return string
			 */
		public function getTitle(){}

		/**
			 * Returns the last document update date as UNIX timestamp
			 * @return int
			 */
		public function getUpdatedAt(){}

		/**
			 * @return int
			 */
		public function getUserId(){}

		/**
			 * @param int[]|string[] $attachments
			 *
			 * @return SearchIndexRecord
			 */
		public function setAttachments($attachments){}

		/**
			 * @param string $indexContent
			 *
			 * @return SearchIndexRecord
			 */
		public function setIndexContent($indexContent){}

		/**
			 * @param string $locale
			 *
			 * @return SearchIndexRecord
			 */
		public function setLocale($locale){}

		/**
			 * Used by Pre-Processing Logic to store / get additional data during indexing
			 * @param string $fieldId
			 * @param $value
			 */
		public function setPreProcessingData($fieldId, $value){}

		/**
			 * @param int $relatedPostId
			 *
			 * @return SearchIndexRecord
			 */
		public function setRelatedPostId($relatedPostId){}

		/**
			 * Mark this Index Record for deletion during indexing process
			 * @param bool True for removal
			 */
		public function setRemoveFromIndex($removeFromIndex = true){}

		/**
			 * @param string $summary
			 *
			 * @return SearchIndexRecord
			 */
		public function setSummary($summary){}

		/**
			 * @param string $title
			 *
			 * @return SearchIndexRecord
			 */
		public function setTitle($title){}

	}
} 

namespace XELOS\Modules\Search\Action{

	class IndexerAction
	{

		/**
			 * Current Search Engine Backend
			 * @var \XELOS\Modules\Search\Interfaces\SearchAdapterInterface
			 */
		private $CurrentSearchAdapter;

		/**
			 * @var \XELOS\Modules\Search\SearchController
			 */
		public $mod;



		/**
			 * Adds the passed SearchIndexRecord to the search index
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 * @return mixed
			 */
		public function addToIndex(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord, $applyPreProcessors = true){}

		/**
			 * Filters the passed SearchIndexRecord's attachments to avoid indexing of non-searchable content
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 */
		private function applyAttachmentFilter(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * Index file attachments and stores the data in the preProcessingData fields 'attachment_index_content' and 'attachment_file_types'
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 */
		private function applyAttachmentIndexer(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * Applies available PreProcess hooks on the passed SearchIndexRecord
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 * @throws \Exception
			 */
		private function applyPreProcessHooks(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * Extracts potential tags and adds them to preProcessingData field 'tags'
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 * @throws \Exception
			 */
		private function applyTagIndexer(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * Returns the currently used Search Adapter
			 * @return \XELOS\Modules\Search\Interfaces\SearchAdapterInterface
			 */
		public function getSearchAdapter(){}

		/**
			 * Applies PreProcessors to the passed Search Index Record
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 */
		private function preProcessSearchIndexRecord(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * Removed the passed Document from the search index
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $DocumentIndex
			 * @return mixed
			 */
		public function removeFromIndex(\XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex){}

	}
} 

namespace XELOS\Modules\Search\Adapter{

	/**
	 * Elastic Search Adapter
	 * Uses an Elastic Search Server for indexing and search operations in XELOS
	 *
	 * @package XELOS\Modules\Search\Adapter
	 */
	class ElasticSearchAdapter implements \XELOS\Modules\Search\Interfaces\SearchAdapterInterface
	{

		/**
			 * Elastic Search Client - is initialized on first getElasticSearchClient() call
			 * @var \Elasticsearch\Client
			 */
		private $elastic_client;

		/**
			 * @var string Elastic Search Index ID
			 */
		private $elastic_index_name;

		/**
			 * @var string Elastic Search Default Document Type Name
			 */
		private $elastic_type_name;

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * Helper to clean HTML input
			 *
			 * @param String $input
			 *
			 * @return mixed|string|string[]|null
			 */
		private function _clean_input($input){}

		/**
			 * Create Index Structure
			 */
		public function _create_index(){}

		/**
			 * @return array
			 */
		private function _get_index_structure(){}

		/**
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 *
			 * @return array|bool
			 */
		public function addToIndex(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * @inheritdoc
			 */
		public function cleanIndex(){}

		/**
			 * @desc Initialize Lucene Search Index
			 * @throws \Elasticsearch\Common\Exceptions\NoNodesAvailableException
			 * @throws \Exception
			 */
		private function connect(){}

		/**
			 * Returns a connected Elastic Search Client Object
			 * @todo Make private as soon as old elastic search document has been migrated
			 * @return \Elasticsearch\Client
			 */
		public function getElasticSearchClient(){}

		/**
			 * @inheritdoc
			 */
		public function getIndexInfo(){}

		/**
			 * Returns true if the index schema is uptodate, false if not.
			 *
			 * @return bool
			 */
		public function is_index_schema_uptodate(){}

		/**
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $DocumentIndex
			 *
			 * @return array|bool
			 */
		public function removeFromIndex(\XELOS\Framework\XF\System\Model\DocumentIndex $DocumentIndex){}

		/**
			 * Used during Module Transition to allow a partial move to new Adapter Design
			 *
			 * @param $mod SearchController
			 */
		public function setMod($mod){}

	}

	/**
	 * Class SqlSearchAdapter
	 *
	 * @package XELOS\Modules\Search\Adapter
	 */
	class SqlSearchAdapter implements \XELOS\Modules\Search\Interfaces\SearchAdapterInterface
	{

		/**
			 * @var \XELOS\Modules\Search\SearchController
			 */
		private $mod;



		/**
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord
			 */
		public function addToIndex(\XELOS\Modules\Search\SearchIndexRecord $searchIndexRecord){}

		/**
			 * @inheritdoc
			 */
		public function cleanIndex(){}

		/**
			 * @inheritdoc
			 */
		public function getIndexInfo(){}

		/**
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $DocumentIndex
			 */
		public function removeFromIndex(\XELOS\Framework\XF\System\Model\DocumentIndex $DocumentIndex){}

		/**
			 * Used during Module Transition to allow a partial move to new Adapter Design
			 * @param $mod SearchController
			 */
		public function setMod($mod){}

	}
} 

namespace XELOS\Modules\Search\Interfaces{

	/**
	 * Interface SearchDocumentInterface
	 * @package XELOS\Modules\Search\Interfaces
	 */
	interface SearchDocumentInterface
	{



		/**
			 * Returns facet search data based on the last search query.
			 *
			 * @return array
			 */
		public function get_facetted_search_info();

	}

	interface SearchPreprocessorInterface
	{



		/**
			 * This function is called for each indexed document and gets an array with the SearchIndexRecords of this specific document.
			 * The PreProcessor can modify these search index records before they will be commited to the search index (e.g.
			 * add additional index content, add language variants etc.)
			 * The functions must return an array with the modified SearchIndexRecords
			 *
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchDocument
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 */
		public function preProcessDocument(\XELOS\Modules\Search\SearchIndexRecord $searchDocument);

	}
} 

namespace XELOS\Modules\Search\Model{

	/**
	 * Class DocumentElasticsearch
	 *
	 * @package XELOS\Modules\Search\Model
	 */
	class DocumentElasticsearch extends \XELOS\Framework\Module\Model\Model implements \XELOS\Modules\Search\Interfaces\SearchDocumentInterface, \XELOS\Modules\Search\Interfaces\SearchAdapterInterfaceLegacy
	{

		 
		private $active_facets;

		/**
			 * @var \Elasticsearch\Client
			 */
		private $elastic_client;

		 
		private $elastic_index_name;

		 
		private $elastic_type_name;

		 
		private $last_search_params;

		 
		private $last_search_result;

		 
		private $last_search_result_filtered;

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;

		 
		protected $properties;



		/**
			 * DocumentElasticsearch constructor.
			 *
			 * @param bool|string $instance_id
			 * @param bool|int $post_id
			 * @param bool|int $post_type
			 * @param bool|int $document_index_id
			 */
		public function __construct($instance_id = false, $post_id = false, $post_type = false, $document_index_id = false){}

		/**
			 * Elastic Search has Reserved Characters which need escaping
			 * https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-query-string-query.html#_reserved_characters
			 *
			 * @param string $term Query Term (e.g. "my" + "search")
			 * @param bool   $allow_advanced_search
			 *
			 * @return string Escaped Query Term (e.g. \"my\" \+ \"search\")
			 */
		private function _escape_query($term, $allow_advanced_search = true){}

		/**
			 * @inheritdoc
			 */
		public function delete(){}

		/**
			 * @inheritdoc
			 */
		public function get_document_count_by_search($searchterm, $instance_id = NULL, $post_type = -1, $limit = array ( ), $advanced_options = array ( ), $facetted_search = array ( )){}

		/**
			 * @inheritdoc
			 */
		public function get_documents_by_search($searchterm, $instance_id = NULL, $post_type = -1, $limit = array ( ), $advanced_options = array ( ), $facetted_search = array ( ), $term = NULL){}

		/**
			 * @inheritdoc
			 */
		public function get_facetted_search_info(){}

		/**
			 * Get Index Settings
			 *
			 * @return array
			 */
		public function get_index_setting(){}

		/**
			 * Returns the number of total results (unlimited) of the last search
			 * @return mixed
			 */
		public function get_last_search_total_result_count(){}

		/**
		 * Class DocumentElasticsearch
		 *
		 * @package XELOS\Modules\Search\Model
		 */
		public function get_min_length(){}

		/**
			 * @inheritdoc
			 */
		public function init($auto_load = true){}

		/**
			 * @inheritdoc
			 */
		public function save(){}

	}

	/**
	 * Class DocumentSql
	 * Search Document using mySQL Fulltext Search
	 * @package XELOS\Modules\Search\Model
	 */
	class DocumentSql extends \XELOS\Framework\Module\Model\Model implements \XELOS\Modules\Search\Interfaces\SearchDocumentInterface, \XELOS\Modules\Search\Interfaces\SearchAdapterInterfaceLegacy
	{

		 
		protected $facetted_search;

		 
		protected $facetted_search_fields;

		 
		protected $max_result_count;

		 
		protected $max_score;

		 
		protected $min_length;

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;

		 
		protected $properties;

		/**
			 * MySQL boolean search operators
			 * @var array
			 * @see https://dev.mysql.com/doc/refman/5.6/en/fulltext-boolean.html
			 */
		private $reserved_operators;

		 
		protected $tag_weight_factor;

		/** @desc weight of additional title score added to score * */
		protected $title_weight_factor;



		/**
			 * DocumentSql constructor.
			 *
			 * @param bool $instance_id
			 * @param bool $resolve_id
			 * @param bool $post_type
			 */
		public function __construct($instance_id = false, $resolve_id = false, $post_type = false){}

		/**
		 * Class DocumentSql
		 * Search Document using mySQL Fulltext Search
		 * @package XELOS\Modules\Search\Model
		 */
		public function _cb_language_sort($lang_a, $lang_b){}

		/**
			 * Generates SQL Query by passed parameters
			 *
			 * @param string  $searchterm
			 * @param string  $instance_id
			 * @param int     $post_type
			 * @param boolean $count_only
			 * @param array   $limit meaning depending of the count of elements, e.g.
			 *                       [1 element]    => array(LIMIT)
			 *                       [2 elements]  => array(OFFSET, LIMIT)
			 *
			 * @param mixed   $advanced_options
			 * @param mixed   $facetted_search
			 * @param xmodel_search_term $term
			 *
			 * @return string
			 */
		private function build_search_query($searchterm, $instance_id = NULL, $post_type = -1, $count_only = false, $limit = array ( ), $advanced_options = false, $facetted_search = false, $term = NULL){}

		/**
			 * Checks if the searchterm contains one of the MySQL boolean search operators or a percent symbol
			 * @see https://dev.mysql.com/doc/refman/5.6/en/fulltext-boolean.html
			 *
			 * @param $searchterm
			 *
			 * @return bool
			 */
		private function contains_advanced_operators($searchterm){}

		/**
			 * @inheritdoc
			 */
		public function delete(){}

		/**
			 * @desc Search for "Documents"
			 *
			 * @inheritdoc
			 *
			 * @returns array [LOCALE > int count]
			 */
		public function get_document_count_by_search($searchterm, $instance_id = NULL, $post_type = -1, $no_limit = false, $advanced_options = false, $facetted_search = false){}

		/**
			 * @desc Returns all posts that are in the passed id list
			 *
			 * @param array ID List Array with document ids, e.g. {1=>{post_id=>1, post_type=0, instance_id='test'}, 2=>....}
			 *
			 * @return array 1-Dim Array with document objects
			 */
		public function get_documents_by_idlist($idlist){}

		/**
			 * @param string $searchterm
			 * @param null $instance_id
			 * @param int  $post_type
			 * @param bool $limit
			 * @param bool $advanced_options
			 * @param bool $facetted_search
			 * @param null $term
			 *
			 * @return array|bool
			 * @throws \ReflectionException
			 */
		public function get_documents_by_search($searchterm, $instance_id = NULL, $post_type = -1, $limit = false, $advanced_options = false, $facetted_search = false, $term = NULL){}

		/**
			 * @inheritdoc
			 */
		public function get_facetted_search_info(){}

		/**
			 * Returns the min length of a single search word
			 */
		public function get_min_length(){}

		/**
			 * Return searchterm suggestions
			 *
			 * @param string Query
			 *
			 * @return array
			 */
		public function get_searchterm_suggest($searchterm){}

		/**
			 * @param bool $auto_load
			 */
		public function init($auto_load = true){}

		/**
			 * Maintenance CRON
			 */
		public function maintenance_cron(){}

		/**
			 * @inheritdoc
			 */
		public function save(){}

		/**
			 * @param string|array $var
			 */
		public function set_file_types($var){}

		/**
			 * Checks if the searchterm is using one of the MySQL boolean search operators.
			 * @see https://dev.mysql.com/doc/refman/5.6/en/fulltext-boolean.html
			 *
			 * @param $searchterm
			 *
			 * @return bool
			 */
		private function uses_advanced_operators($searchterm){}

	}

	/**
		*@desc Search Agent Model
		*/
	class Searchagent extends \XELOS\Framework\Module\Model\Model
	{

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
				 * @param bool $limit
				 * @param bool $since
				 *
				 * @return mixed
				 */
		public function get_search_result_count($limit = false, $since = false){}

		/**
			*@desc Search Agent Model
			*/
		public function get_search_results($limit = false, $since = false){}

		/**
			*@desc Search Agent Model
			*/
		public function update_agent(){}

	}

	class Term extends \XELOS\Framework\Module\Model\Model
	{

		 
		protected $table_auto_properties;

		 
		protected $table_name;



	}
} 

namespace XELOS\Modules\Search\Page{

	/**
	 * @desc Main Class
	 * @ingroup SearchController
	 */
	class IndexPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * Show Page as Index
			 *
			 * @param string $tag
			 * @param string $title
			 *
			 * @return \XELOS\Framework\Core\xelos_template|xelos_global_template
			 * @throws Exception
			 */
		public function get_page($tag = NULL, $title = ''){}

	}

	/**
	* @desc Page: Maintenance
	* @ingroup SearchController
	*/
	class MaintenancePage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * Index Maintenance Page
			 *
			 */
		public function get_page(){}

	}

	/**
	* @desc Page: Open Search
	* @ingroup SearchController
	*/
	class OpensearchPage extends \XELOS\Framework\Module\Page\Page
	{



		/**
		* @desc Page: Open Search
		* @ingroup SearchController
		*/
		public function get_page($page = 'xml'){}

	}

	/**
	 * @desc Page: Overview
	 * @ingroup SearchController
	 */
	class OverviewPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
		 * @desc Page: Overview
		 * @ingroup SearchController
		 */
		private function get_instance_breadcrumb($instance, $instances = NULL){}

		/**
			 * Main Search Page
			 *
			 * @param mixed $args
			 * @param mixed $mode
			 *
			 * @return xelos_global_template
			 * @throws Exception
			 */
		public function get_page($args = NULL, $mode = 'list'){}

	}

	/**
	* @desc Page: Search Agent
	* @ingroup SearchController
	*/
	class SearchagentPage extends \XELOS\Framework\Module\Page\Page
	{



		/**
		* @desc Page: Search Agent
		* @ingroup SearchController
		*/
		public function _cb_searchagent_get_result_count($id){}

		/**
			 * Search Agent
			 */
		public function get_page(){}

		/**
		* @desc Page: Search Agent
		* @ingroup SearchController
		*/
		public function get_searchagent_tabs($current = false){}

		/**
		* @desc Page: Search Agent
		* @ingroup SearchController
		*/
		public function searchagent_table_cb($id, $query){}

		/**
		* @desc Page: Search Agent
		* @ingroup SearchController
		*/
		public function searchagent_table_cb_result_count($id){}

	}

	/**
	* @desc Page: Settings
	* @ingroup SearchController
	*/
	class SettingsPage extends \XELOS\Framework\Module\Page\Page
	{



		/**
			 * Search System Settings
			 */
		public function get_page(){}

	}

	/**
	* @desc Page: Suggest
	* @ingroup SearchController
	*/
	class SuggestPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * Auto-Suggest Feature
			 * @inheritdoc
			 */
		public function get_page($sub_page = NULL){}

	}
} 

namespace XELOS\Modules\Search\UI{

	/**
	* Search Results XUI Panel
	*/
	class ResultPanel extends \XELOS\Framework\Module\UI\UIAjaxComponent
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;

		 
		private $single_facetted_option;



		/**
		* Search Results XUI Panel
		*/
		private function build_facetted_search_parameter($facetted_search, $field, $value, $remove = false){}

		/**
		  * Returns all available integration links for the search
		  *
		  * @param mixed $query
		  */
		private function get_integration_links($q){}

		/**
			 * @desc Display Result Page fills Template appropriately
			 * @throws Exception
			 */
		private function get_results(){}

		/**
		* Search Results XUI Panel
		*/
		protected function render_xui(){}

	}
} 

namespace XELOS\Modules\Search\Hook\Portal{

	/**
		* @desc Portal Portlet, internal use only
		*/
	class AgentPortletShowPortlet extends \XELOS\Framework\XF\UI\Portlet
	{



		/**
			  * @desc Constructor
			  */
		public function __construct(){}

		/**
			  * @desc Return HTML
			  */
		public function get_html($size = 'default'){}

		/**
			  * @desc Return Title String
			  */
		public function get_title(){}

	}

	/**
		* @desc Portal Portlet, internal use only
		*/
	class SearchPortletShowPortlet extends \XELOS\Framework\XF\UI\Portlet
	{

		 
		public $meta_info;

		 
		public $portlet_config;



		/**
			  * @desc Constructor
			  */
		public function __construct(){}

		/**
			* @desc Portal Portlet, internal use only
			*/
		public function get_fdl(){}

		/**
			  * @desc Return HTML
			  */
		public function get_html($size = 'default'){}

		/**
			  * @desc Return Title String
			  */
		public function get_title(){}

	}
} 

namespace XELOS\Modules\Search\Hook\Selector{

	/**
	 * Class SearchSelectorBrowser
	 */
	class SearchSelectorBrowser implements \XELOS\Modules\Selector\Interfaces\DocumentBrowserHookInterface
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * @inheritdoc
			 */
		public function get_document_browser(){}

		/**
			 * @inheritdoc
			 */
		public function get_name(){}

		/**
			 * @inheritdoc
			 */
		public function get_thumbnail_url(){}

		/**
			 * Checks whether this browser is consented.
			 *
			 * @return bool
			 */
		public function is_consented(){}

	}
} 

namespace XELOS\Modules\Search\Hook\System{

	class UpdateSearchIndexDocumentIndexEvent extends \XELOS\Framework\Module\Hook\IndexEventHook implements \XELOS\Framework\Core\Interfaces\IndexEventInterface
	{

		/** @var \XELOS\Modules\Search\SearchController */
		public $mod;



		/**
			 * Update / Delete Search Index corresponding to document index
			 *
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
			 * @param string                                         $event
			 * @param int                                            $event_user_id
			 *
			 * @return null
			 * @throws Exception
			 */
		public function process_document_index($document_index, $event, $event_user_id = NULL){}

	}
} 

namespace XELOS\Modules\Search\Hook\SystemStatus{

	class SearchCheckSystemStatusCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{

		/**
			 * @var \XELOS\Modules\Search\SearchController
			 */
		public $mod;



		public function __construct(){}

		public function run_check(){}

	}
} 

namespace XELOS\Modules\Search\Hook\Selector\Component{

	/**
	 * Class SearchDocumentBrowser
	 * @package XELOS\Modules\Search\Selector
	 */
	class SearchDocumentBrowser extends \XELOS\Modules\Selector\Abstracts\AbstractDocumentBrowser implements \XELOS\Modules\Selector\Interfaces\SearchableDocumentBrowserInterface
	{

		/** @var \XELOS\Modules\Search\SearchController */
		protected $mod;



		/**
			 * SearchDocumentBrowser constructor.
			 *
			 * @param \XELOS\Modules\Search\SearchController $mod
			 */
		public function __construct(\XELOS\Modules\Search\SearchController $mod){}

		/**
			 * @inheritdoc
			 */
		public function get_items($id, $offset){}

		/**
			 * Returns all items found by given term.
			 *
			 * @param $term
			 *
			 * @return mixed
			 */
		public function get_items_by_search($term){}

		/**
			 * Returns a title for this browser.
			 *
			 * @param $item_id
			 *
			 * @return string
			 */
		public function get_title($item_id){}

	}
} 

