<?php
namespace {
}



namespace XELOS\Modules\SystemStatus{

	/**
	 * Class Main
	 * @package XELOS\Modules\SystemStatus
	 *
	 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\SystemStatusControllerDocumentation
	 */
	class SystemStatusController extends \XELOS\Framework\Module\Controller implements \XELOS\Framework\Core\Interfaces\ModuleInterface
	{



		/**
		   * Gets all active hooks and removes old results of inactive or non existing checks
		   */
		public function discard_old_results(){}

		/**
			 * Get Node Model for the server this script is running on
			 * @return \XELOS\Modules\SystemStatus\Model\Node
			 */
		public function get_current_node(){}

		/**
			 * Returns an array of all checks and their last results
			 *
			 * @param \XELOS\Framework\Module\Model\ModelCollection $filter_nodes Get Checks for the specified nodes
			 *
			 * @return \XELOS\Modules\SystemStatus\Model\Check[]|\XELOS\Framework\Module\Model\ModelCollection array ['result'=>ServiceCheckResult()]
			 */
		public function get_system_check_results(\XELOS\Framework\Module\Model\ModelCollection $filter_nodes = NULL){}

		/**
		   * Returns the current overall system check across all checks
		   * This call does not execute any checks but summarizes all existing check results
			 * @param \XELOS\Framework\Module\Model\ModelCollection $filter_nodes Get Checks for the specified nodes
		   * @return array
		   */
		public function get_system_status(\XELOS\Framework\Module\Model\ModelCollection $filter_nodes = NULL){}

		/**
		   * Runs all available checks and stores the results in the database
			 * @return int count of checks processed
		   */
		public function run_all_checks(){}

		/**
		   * @desc Runs one or all checks of the specified instance
		   * @param $instance_id
		   * @param string $check_id Internal ID of the Check (as defined by instance Service Check)
		   * @return array
		   */
		public function run_check($instance_id, $check_id = '*'){}

	}
} 

namespace XELOS\Modules\SystemStatus\Interfaces{

	/**
		 * Class ServiceCheck
		 * @package XELOS\Modules\SystemStatus\Interfaces
		 *
		 */
	abstract class ServiceCheck
	{

		/**
				 * @var string CSS Icon Class (e.g. icon-circle)
				 */
		protected $icon;

		/** @var \XELOS\Framework\Module\Controller */
		public $mod;

		/**
				 * @var string node or global -> specifies if the check should be run on all nodes or only a single node of a cluster (not yet supported)
				 */
		protected $scope;

		/**
				 * @var bool Set to true if this check should be skipped - e.g. if prerequisites are not met
				 */
		protected $skip_check;

		/**
				 * @var string Title of this Check (i18n)
				 */
		protected $title;



		/**
				 * Returns all relevant details for this check as title, scope and icon
				 * @return array
				 */
		public function get_details(){}

		/**
				 * @desc Returns all available checks
				 * @return string
				 */
		public function get_title(){}

		/**
				 * Run this Check and return Result
				 * @return ServiceCheckResult
				 */
		abstract public function run_check();

		/**
				 * Returns true if this check should be skipped
				 * @return bool
				 */
		public function skip_check(){}

	}

	class ServiceCheckResult
	{

		 
		public static $SEVERITY_CRITICAL = 'critical';

		 
		public static $SEVERITY_LOW = 'low';

		 
		public static $SEVERITY_MEDIUM = 'med';

		 
		public static $STATE_GREEN = 'green';

		 
		public static $STATE_ORANGE = 'orange';

		 
		public static $STATE_RED = 'red';

		 
		public static $TYPE_PERFORMANCE = 'performance';

		 
		public static $TYPE_STABILITY = 'stability';

		 
		public $details;

		 
		public $icon;

		 
		public $message;

		/**
				 * Importance of this check for the overall system stability
				 * @var string ServiceCheckResult::$SEVERITY_LOW, ServiceCheckResult::$SEVERITY_MEDIUM, ServiceCheckResult::$SEVERITY_CRITICAL
				 */
		public $severity;

		/**
				 * Status of the Check. The signal light can have three states: red -> CRITICAL, orange -> NEEDS ATTENTION, green -> ALL SYSTEMS OK
				 * @var string ServiceCheckResult::$STATE_GREEN,ServiceCheckResult::$STATE_ORANGE,ServiceCheckResult::$STATE_RED
				 */
		public $state;

		 
		public $title;

		/**
				 * Type of influence on system -> Performance, Stability
				 * @var string
				 */
		public $type;



		public function __construct($state, $message, $details = ''){}

	}
} 

namespace XELOS\Modules\SystemStatus\Model{

	/**
	 *
	 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\CheckDocumentation
	 *
	 * @method bool|Node find_by_instance_id_and_check_id_and_node_id(string|string[] $instance_id, string $check_id, int $node_id, $sql_params = false)
	 * @method \XELOS\Framework\Module\Model\ModelCollection|Check[]  find_all_by_instance_id_and_check_id_and_active(string|string[] $instance_id, string $check_id, int $active, $sql_params = false)
	 * @method \XELOS\Framework\Module\Model\ModelCollection|Check[]  find_all_by_node_id(int|int[] $node_id, $sql_params = false)
	 * @method int count_by_state_and_active_and_node_id(string $state, int $active, int|int[] $node_id)
	 *
	 * @property-read \XELOS\Modules\SystemStatus\SystemStatusController $mod
	 */
	class Check extends \XELOS\Framework\Module\Model\Model
	{

		/**
			 * Has State Machine beein initialized yet (registered event listeners)
			 * @var bool
			 */
		protected $_state_machine_active;

		/**
			 * Array of all fields and their values which have been changed during the last save() call
			 * @var bool
			 */
		protected $_state_machine_field_transitions;

		/**
			 * List of registered transitions which will be checked on field changes
			 * @var array
			 */
		protected $_state_machine_registered_transitions;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 *
		 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\CheckDocumentation
		 *
		 * @method bool|Node find_by_instance_id_and_check_id_and_node_id(string|string[] $instance_id, string $check_id, int $node_id, $sql_params = false)
		 * @method \XELOS\Framework\Module\Model\ModelCollection|Check[]  find_all_by_instance_id_and_check_id_and_active(string|string[] $instance_id, string $check_id, int $active, $sql_params = false)
		 * @method \XELOS\Framework\Module\Model\ModelCollection|Check[]  find_all_by_node_id(int|int[] $node_id, $sql_params = false)
		 * @method int count_by_state_and_active_and_node_id(string $state, int $active, int|int[] $node_id)
		 *
		 * @property-read \XELOS\Modules\SystemStatus\SystemStatusController $mod
		 */
		public function __construct($id = false){}

		/**
			 * afterSave Event Handler
			 * Process State Machine after Save
			 */
		public function _state_machine_after_save(){}

		/**
			 * beforeSave Event Handler
			 * Identify all properties which will be modified with this call
			 */
		public function _state_machine_before_save(){}

		/**
			 * Checks if the passed value matches the specified rule
			 * @param $value
			 * @param $rule
			 * @return bool
			 */
		private function _state_machine_matches_rule($value, $rule){}

		/**
			 * Register Transition Callback which will be called when field values change according to defined transition
			 * @param string $property_id Property Field which should be monitored
			 * @param mixed $from_value Single start value or array of values
			 * @param mixed $to_value Single target value or array of values
			 * @param $callback Callback function, receives parameters: Model Object, FROM Value, TO Value of field
			 */
		protected function after_transition($property_id, $from_value, $to_value, $callback){}

		/**
			 * Returns the check results as ServiceCheckResult item
			 * @return \XELOS\Modules\SystemStatus\Interfaces\ServiceCheckResult
			 */
		public function get_check_result(){}

		/**
			 * Sends a notification about this check to the administrators of this system
			 * @throws \Exception
			 */
		public function notify_user(){}

		/**
			 * Runs this check
			 */
		public function run(){}

	}

	/**
	 *
	 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\NodeDocumentation
	 *
	 * @method bool|Node find_by_node_name(string $node_name, $sql_params = false)
	 * @method \XELOS\Framework\Module\Model\ModelCollection|Node[] find_all_by_active(int $active, $sql_params = false)
	 */
	class Node extends \XELOS\Framework\Module\Model\Model
	{

		/** @var \XELOS\Modules\SystemStatus\SystemStatusController */
		public $mod;

		 
		protected $properties;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 *
		 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\NodeDocumentation
		 *
		 * @method bool|Node find_by_node_name(string $node_name, $sql_params = false)
		 * @method \XELOS\Framework\Module\Model\ModelCollection|Node[] find_all_by_active(int $active, $sql_params = false)
		 */
		public function get_operation_info(){}

		/**
		 *
		 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\NodeDocumentation
		 *
		 * @method bool|Node find_by_node_name(string $node_name, $sql_params = false)
		 * @method \XELOS\Framework\Module\Model\ModelCollection|Node[] find_all_by_active(int $active, $sql_params = false)
		 */
		public function get_state(){}

		/**
		 *
		 * @mixin \XELOS\Modules\SystemStatus\Docs\ClassGenerated\Model\NodeDocumentation
		 *
		 * @method bool|Node find_by_node_name(string $node_name, $sql_params = false)
		 * @method \XELOS\Framework\Module\Model\ModelCollection|Node[] find_all_by_active(int $active, $sql_params = false)
		 */
		public function get_title(){}

	}
} 

namespace XELOS\Modules\SystemStatus\Page{

	class MinimalPage extends \XELOS\Framework\Module\Page\Page
	{

		 
		public $_core_checks;

		/** @var \XELOS\Modules\SystemStatus\SystemStatusController */
		public $mod;



		/**
			 * Accessor for Node Info to be used in monitoring software
			 *
			 * @param string $format
			 *
			 * @return string JSON Info
			 */
		public function page_nodes($format = 'json'){}

		/**
			 * @return string Node Status
			 */
		public function page_overview(){}

		/**
			 * Accessor for URL /system_status/minimal/run_checks
			 * This allows to check a node without necessarily using a cron from a loadbalancer
			 *
			 * @return string Node Status
			 */
		public function page_run_checks(){}

	}

	class OverviewPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\SystemStatus\SystemStatusController */
		public $mod;



		/**
			 * @param array $args
			 *
			 * @return bool|string|\XELOS\Framework\Core\Template|\xelos_global_template
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 */
		public function get_page($args = array ( )){}

		/**
			 * @param string $action
			 * @param int    $node_id
			 *
			 * @return bool|null|string|\xelos_global_template
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 */
		private function process_cluster_action($action, $node_id){}

		private function run_check($check_id){}

		private function toggle_check_active($check_id){}

	}
} 

namespace XELOS\Modules\SystemStatus\Hook\SystemStatus{

	class CacheCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{

		/** @var \XELOS\Modules\SystemStatus\SystemStatusController */
		public $mod;



		public function __construct(){}

		public function run_check(){}

	}

	class ClamavCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{

		/** @var \XELOS\Modules\SystemStatus\SystemStatusController */
		public $mod;



		public function __construct(){}

		public function run_check(){}

		/**
			 * Returns true if this check should be skipped
			 * @return bool
			 */
		public function skip_check(){}

	}

	class ConnectionCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}

	class CronCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		/**
			 * Checks if the CronJob system is working and if there are any CronJobs with errors
			 * @return \XELOS\Modules\SystemStatus\Interfaces\ServiceCheckResult
			 */
		public function run_check(){}

	}

	class DaemonCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		/**
			 * Checks if all active daemons are working properly
			 * @return \XELOS\Modules\SystemStatus\Interfaces\ServiceCheckResult
			 */
		public function run_check(){}

	}

	class DatabaseCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}

	class DiskCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}

	class DocumentIndexCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}

	class LicenseCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}

	/**
	 * Class RepoCheck
	 * @package XELOS\Modules\SystemStatus\Hook
	 *
	 * @property-read \XELOS\Modules\SystemStatus\SystemStatusController $mod
	 */
	class RepoCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		/**
		 * Class RepoCheck
		 * @package XELOS\Modules\SystemStatus\Hook
		 *
		 * @property-read \XELOS\Modules\SystemStatus\SystemStatusController $mod
		 */
		public function __construct(){}

		/**
		 * Class RepoCheck
		 * @package XELOS\Modules\SystemStatus\Hook
		 *
		 * @property-read \XELOS\Modules\SystemStatus\SystemStatusController $mod
		 */
		public function run_check(){}

	}

	class TimeCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{



		public function __construct(){}

		public function run_check(){}

	}
} 

