<?php
namespace {
}



namespace XELOS\Modules\Translation{

	/**
	 * @package XELOS\Modules\Translation
	 *
	 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\TranslationControllerDocumentation
	 */
	class TranslationController extends \XELOS\Framework\Module\Controller implements \XELOS\Framework\Core\Interfaces\ModuleInterface
	{

		/** @var \XELOS\Modules\Translation\Lib\Api\BaseTranslationApi */
		private $translationApi;



		/**
			 * Called by daemon to process the TranslationJob queue
			 *
			 * @param Callable $logger The callback for logging
			 *
			 * @return bool
			 * @throws \Exception
			 */
		public function daemonProcessQueue($logger){}

		/**
			 * Generates a link to set the disabled state for the translation for $language
			 *
			 * @param string $language The locale ('EN_GB', 'DE_DE', ...)
			 * @param string $setDisabled
			 * @param ?string $caption
			 *
			 * @return string
			 */
		public function getDisableLinkForLanguage($language, $setDisabled = '1', $caption = NULL){}

		/**
			 * Returns the fullpreview/html_content of a DocumentIndex object.
			 *
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
			 *
			 * @return null|string $html_content
			 */
		public function getDocumentIndexHtmlContent(\XELOS\Framework\XF\System\Model\DocumentIndex $document_index){}

		/**
			 * Generates the link for the translation feedback
			 *
			 * @param string $model_name This is either translation or translation_document
			 * @param int    $model_id   The ID of the model
			 *
			 * @return string
			 */
		public function getFeedbackLink($model_name, $model_id){}

		/**
			 * Generates the link to auto translate the i18n form fields
			 * @param string $formName
			 *
			 * @return string
			 */
		public function getFormFieldsTranslationLink($formName){}

		/**
			 * Get translated $content for $target_language
			 *
			 * @param string      $content             The content which should be translated
			 * @param null|string $cache_key           The cache key to use as unique identifier (eg.: 'title' or 'content'
			 *                                         etc.)
			 * @param null|string $target_language     The requested target language
			 * @param null|int    $document_index_id   The document_index_id
			 * @param bool        $add_to_search_index Flag to add the translated content to the search index
			 * @param bool        $request_translation Flag to create translation jobs, if there is no translation yet
			 * @param bool        $force_translation   Force the translation to be executed immediately
			 *
			 * @return array $result The translation result:
			 *               ['content_original'=>[...],'content_translated'=>[...],'improved_by'=>[user_id],'language_source'=>'en','language_target'=>'de','errors'=>[]]
			 * @throws TranslationException|\Exception
			 */
		public function getTranslated($content, $cache_key = NULL, $target_language = NULL, $document_index_id = NULL, $add_to_search_index = true, $request_translation = true, $force_translation = false){}

		/**
			 * Returns the Translation API currently selected in config
			 *
			 * @return Lib\Api\BaseTranslationApi|null
			 */
		public function getTranslationApi(){}

		/**
			 * Tries to find translation model and a possible existing feedback model.
			 *
			 * @param string              $cacheKey
			 * @param string              $contentHash
			 * @param null|int            $documentIndexId
			 * @param \XELOS\Modules\Translation\Model\TranslationFeedback $feedbackModel
			 * @param string              $targetLanguage
			 *
			 * @return Model\Translation|Model\TranslationDocument
			 * @throws \Exception
			 */
		protected function getTranslationModel($cacheKey, $contentHash, $documentIndexId, $feedbackModel, $targetLanguage){}

		/**
			 * Generates the link to the Auto translation settings page (e.g. used in the user link dropdown)
			 * @return string
			 */
		public function getTranslationSettingsLink(){}

		/**
		 * @package XELOS\Modules\Translation
		 *
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\TranslationControllerDocumentation
		 */
		public function hasFeedbackLoop(){}

		/**
		 * @package XELOS\Modules\Translation
		 *
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\TranslationControllerDocumentation
		 */
		public function init(){}

		/**
			 * Returns the state of the disable_background_translations option
			 * @return bool
			 */
		public function isBackgroundTranslationDisabled(){}

		/**
		 * @package XELOS\Modules\Translation
		 *
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\TranslationControllerDocumentation
		 */
		public function isInlineTranslationDisabled(){}

		/**
			 * Check if the translation for the given language is disabled
			 *
			 * @param string $language
			 *
			 * @return bool Is Disabled?
			 */
		public function isTranslationDisabled($language){}

		/**
			 * Checks, if the given $locale is in available_languages
			 * @param $locale
			 *
			 * @return bool
			 */
		public function isValidLocale($locale){}

		/**
			 * Is the $name a valid translation model name?
			 *
			 * @param  string $name The model name
			 *
			 * @return bool         Valid?
			 */
		public function isValidTranslationModelName($name){}

		/**
			 * Sets the config to disable the translation for the given $language based on $disable flag.
			 *
			 * @param string $language
			 * @param bool   $setDisable
			 *
			 * @return void
			 */
		public function setDisableTranslationForLanguage($language, $setDisable = true){}

		/**
			 * Setter for the translation Api
			 * @param \XELOS\Modules\Translation\Lib\Api\BaseTranslationApi $api The Api
			 */
		public function setTranslationApi(\XELOS\Modules\Translation\Lib\Api\BaseTranslationApi $api){}

	}
} 

namespace XELOS\Modules\Translation\Action{

	class FeedbackAction
	{

		/** @var array Maps target language to db language string representation */
		private $lang_strings;

		/** @var TranslationController */
		public $mod;



		/**
			 * Builds a map of available system languages in $lang_strings: ['de' => 'DE_DE', 'en' => 'EN_GB', ...]
			 */
		protected function buildLangStrings(){}

		/**
			 * @param \XELOS\Modules\Translation\Model\TranslationFeedback $feedbackModel
			 * @param bool $forceExecution If true processFeedbackJob() is executed immediately
			 *
			 * @return void
			 */
		public function createFeedbackJob($feedbackModel, $forceExecution = false){}

		/**
			 * Creates a translation_job model
			 *
			 * @param string $content
			 * @param string $target_model
			 * @param int    $target_id
			 * @param string $language
			 * @param bool   $add_to_search_index
			 * @param int    $priority
			 *
			 * @return \XELOS\Modules\Translation\Model\TranslationJob
			 */
		public function createTranslationJob($content, $target_model, $target_id, $language, $add_to_search_index = true, $priority = 1){}

		/**
			 * @param string $language The language to get the db string for eg.: 'de'
			 *
			 * @return string $db_string The i18n db field representation of lang eg.: 'DE_DE'
			 * @throws TranslationException If language string could not be mapped
			 */
		public function getDbLanguageString($language){}

		/**
			 * Getter for $lang_strings
			 *
			 * @return array
			 */
		public function getLangStrings(){}

		/**
			 * @param \XELOS\Modules\Translation\Model\TranslationJob $job
			 *
			 * @return bool Was the job processed successfully
			 */
		public function processFeedbackJob($job){}

	}

	class TranslateAction
	{

		/** @var array Maps target language to db language string representation */
		private $lang_strings;

		/** @var \XELOS\Modules\Translation\TranslationController */
		public $mod;



		/**
			 * Builds a map of available system languages in $lang_strings: ['de' => 'DE_DE', 'en' => 'EN_GB', ...]
			 */
		protected function buildLangStrings(){}

		/**
			 * Creates a translation_job model
			 *
			 * @param string $content
			 * @param string $target_model
			 * @param int    $target_id
			 * @param string $language
			 * @param bool   $add_to_search_index
			 * @param int    $priority
			 *
			 * @return \XELOS\Modules\Translation\Model\TranslationJob
			 */
		public function createTranslationJob($content, $target_model, $target_id, $language, $add_to_search_index = true, $priority = 1){}

		/**
			 * Creates translation jobs in the translation job queue to translate $content into $languages
			 *
			 * @param string $content             The content to translate
			 * @param string $target_model        ['translation_document'|'translation']
			 * @param int    $target_id           The model id
			 * @param array  $languages           Translate to this languages ['DE_DE','EN_GB', ...]
			 * @param bool   $add_to_search_index Flag to add the translations to the search index
			 *
			 * @return void
			 * @throws \Exception
			 */
		public function createTranslationJobs($content, $target_model, $target_id, $languages, $add_to_search_index = false, $priority = 1){}

		/**
			 * @param string $language The language to get the db string for eg.: 'de'
			 *
			 * @return string $db_string The i18n db field representation of lang eg.: 'DE_DE'
			 * @throws TranslationException If language string could not be mapped
			 */
		public function getDbLanguageString($language){}

		/**
			 * Getter for $lang_strings
			 *
			 * @return array
			 */
		public function getLangStrings(){}

		/**
			 * Processes the TranslationJob
			 *
			 * @param \XELOS\Modules\Translation\Model\TranslationJob $translationJob
			 *
			 * @return array $result The translation result:
			 *               ['content_original'=>[...],'content_translated'=>[...],'language_source'=>'en','language_target'=>'de','errors'=>[]]
			 * @throws \Exception
			 */
		public function processTranslationJob(\XELOS\Modules\Translation\Model\TranslationJob $translationJob){}

		/**
			 * @param string $content         The content to translate
			 * @param string $target_language The target language
			 *
			 * @return array
			 */
		public function translate($content, $target_language){}

		/**
			 * Updates the translation_counter table with info about the translated content
			 *
			 * @param string $language
			 * @param string $content
			 * @return void
			 * @throws \Exception
			 */
		protected function updateTranslationCounter($language, $content){}

	}
} 

namespace XELOS\Modules\Translation\Exception{

	class TranslationException extends \Exception implements \Throwable
	{



	}
} 

namespace XELOS\Modules\Translation\Model{

	/**
	 * Class Translation
	 * @package XELOS\Modules\Translation\Model
	 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationDocumentation
	 *
	 */
	class Translation extends \XELOS\Framework\Module\Model\Model
	{

		 
		public static $TRANSLATED_CONTENT_PROPERTY_START = 'content_';

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 * Class Translation
		 * @package XELOS\Modules\Translation\Model
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationDocumentation
		 *
		 */
		public function can_read(){}

		/**
		     * Deletes model and also deletes possible related translation_job models
		     *
		     * @return bool Was delete successful?
		     */
		public function delete(){}

		/**
			 * Returns the content for the given $locale... if there is any
			 * @param string $locale The locale (e.g. 'DE_DE', 'EN_GB', ...)
			 *
			 * @return null|string $content
			 */
		public function getContentForLocale($locale){}

		/**
		     * Determines which language has not translation yet
		     *
		     * @return array $missing The locale strings with empty content
		     */
		public function getMissingTranslations(){}

		/**
		     * Returns the $original_language content if possible
		     *
		     * @return null|string $content
		     */
		public function getOriginalContent(){}

		/**
			 * @return array $translatedContent E.g.: ['DE_DE'=>[...], 'EN_GB' => [...]]
			 */
		public function getTranslatedContent(){}

		/**
		     * Resets/Emptys all content related to the translation
		     *
		     * @return void
		     */
		public function resetContent(){}

	}

	/**
	 * Class TranslationDocument
	 * @package XELOS\Modules\Translation\Model
	 *
	 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationDocumentDocumentation
	 * @method TranslationDocument find_by_document_index_id_and_cache_key(int $id, string $cache_key, $sql_params = false) Returns Model for document index id and cache key
	 * @method TranslationDocument[] find_all_by_document_index_id(int $id, $sql_params = false) Finds all translation models for document_index_id
	 */
	class TranslationDocument extends \XELOS\Framework\Module\Model\Model
	{

		 
		public static $TRANSLATED_CONTENT_PROPERTY_START = 'content_';

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 * Class TranslationDocument
		 * @package XELOS\Modules\Translation\Model
		 *
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationDocumentDocumentation
		 * @method TranslationDocument find_by_document_index_id_and_cache_key(int $id, string $cache_key, $sql_params = false) Returns Model for document index id and cache key
		 * @method TranslationDocument[] find_all_by_document_index_id(int $id, $sql_params = false) Finds all translation models for document_index_id
		 */
		public function can_read(){}

		/**
		     * Deletes model and also deletes possible related translation_job models
		     *
		     * @return bool Was delete successful?
		     */
		public function delete(){}

		/**
			 * Returns the content for the given $locale... if there is any
			 * @param string $locale The locale (e.g. 'DE_DE', 'EN_GB', ...)
			 *
			 * @return null|string $content
			 */
		public function getContentForLocale($locale){}

		/**
		     * Determines which language has not translation yet
		     *
		     * @return array $missing The locale strings with empty content
		     */
		public function getMissingTranslations(){}

		/**
		     * Returns the $original_language content if possible
		     *
		     * @return null|string $content
		     */
		public function getOriginalContent(){}

		/**
			 * @return array $translatedContent E.g.: ['DE_DE'=>[...], 'EN_GB' => [...]]
			 */
		public function getTranslatedContent(){}

		/**
		     * Resets/Emptys all content related to the translation
		     *
		     * @return void
		     */
		public function resetContent(){}

	}

	/**
	 * Class Translation
	 * @package XELOS\Modules\Translation\Model
	 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationFeedbackDocumentation
	 * @method TranslationFeedback find_by_source_model_and_source_id_and_target_language(string $source_model, int $id, string $language, $sql_params = false)
	 */
	class TranslationFeedback extends \XELOS\Framework\Module\Model\Model
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;

		 
		protected $sourceModel;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 * Class Translation
		 * @package XELOS\Modules\Translation\Model
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationFeedbackDocumentation
		 * @method TranslationFeedback find_by_source_model_and_source_id_and_target_language(string $source_model, int $id, string $language, $sql_params = false)
		 */
		public function can_read(){}

		/**
			 * Deletes model and also deletes possible related translation_job models
			 *
			 * @return bool Was delete successful?
			 */
		public function delete(){}

		/**
			 * Get the original auto translation from the source model for $language
			 *
			 * @param string $language The language to get the auto translation for (e.g.: 'DE_DE')
			 *
			 * @return bool|mixed|null
			 */
		public function getSourceAutoTranslationForLanguage($language){}

		/**
			 * Get the original content of the source
			 *
			 * @return string|null The original content string
			 */
		public function getSourceContent(){}

		/**
			 * Get the original_language field of the source model
			 *
			 * @return string|null The language string ('DE_DE', ...)
			 */
		public function getSourceLanguage(){}

		/**
			 * Returns the source Translation model for which this model is the feedback/improved translation
			 *
			 * @return Translation|TranslationDocument|null
			 */
		public function getSourceModel(){}

	}

	/**
	 * Class Translation
	 * @package XELOS\Modules\Translation\Model
	 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationJobDocumentation
	 *
	 * @method \XELOS\Framework\Module\Model\ModelCollection|TranslationJob[] find_all_by_target_model_and_error_count(string[] $target_model, array $error_count, $sql_params = false) Returns jobs of target_model(s) with error count restriction
	 * @method \XELOS\Framework\Module\Model\ModelCollection|TranslationJob[] find_all_by_target_model_and_target_id(string $target_model, int $target_id, $sql_params = false) Returns jobs of target_model and target_id
	 * @method int count_by_target_model_and_target_id(string $target_model, int $target_id, $sql_params = false) Returns count of jobs of target_model and target_id
	 */
	class TranslationJob extends \XELOS\Framework\Module\Model\Model
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;

		 
		protected $table_auto_properties;

		 
		protected $table_name;



		/**
		 * Class Translation
		 * @package XELOS\Modules\Translation\Model
		 * @mixin \XELOS\Modules\Translation\Docs\ClassGenerated\Model\TranslationJobDocumentation
		 *
		 * @method \XELOS\Framework\Module\Model\ModelCollection|TranslationJob[] find_all_by_target_model_and_error_count(string[] $target_model, array $error_count, $sql_params = false) Returns jobs of target_model(s) with error count restriction
		 * @method \XELOS\Framework\Module\Model\ModelCollection|TranslationJob[] find_all_by_target_model_and_target_id(string $target_model, int $target_id, $sql_params = false) Returns jobs of target_model and target_id
		 * @method int count_by_target_model_and_target_id(string $target_model, int $target_id, $sql_params = false) Returns count of jobs of target_model and target_id
		 */
		public function can_read(){}

	}
} 

namespace XELOS\Modules\Translation\Page{

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class AjaxtranslatePage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 * @throws TranslationException
			 */
		public function page_overview(){}

	}

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class FeedbackPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * @param bool|mixed $modelName
			 *
			 * @return \XELOS\Framework\Core\Template|\xelos_global_template
			 * @throws ContentException|TranslationException
			 */
		public function get_page($modelName = false){}

		/**
			 * The page to edit the improved translation
			 * @param \XELOS\Modules\Translation\Model\Translation|\XELOS\Modules\Translation\Model\TranslationDocument $model
			 * @throws ContentException|\XELOS\Modules\Translation\Model\TranslationException
			 * @return bool|string|\XELOS\Framework\Core\Template
			 */
		public function page_overview($model){}

	}

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class FormtranslatePage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * @throws \XELOS\Framework\Core\Exception\ContentException
			 * @throws TranslationException
			 */
		public function page_overview(){}

	}

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class SettingsPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * Page to set the disabled state to $setDisbaled for the specified $language
			 *
			 * @param string $language    The language locale (DE_DE, EN_GB, ...)
			 * @param string $setDisabled Should the translation be disabled?
			 */
		public function page_language($language, $setDisabled = '1'){}

		/**
			 * Set the auto translation of content to disabled(!). Auto translation is enabled, if no
			 *
			 * @return \XELOS\Framework\Core\Template
			 * @throws ContentException
			 */
		public function page_overview(){}

	}

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class StatisticsPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * Shows statistics of the requested translations
			 * @return \XELOS\Framework\Core\Template
			 * @throws ContentException
			 */
		public function page_overview(){}

	}

	/**
	 * Pages for the GECKO registration process.
	 *
	 * @package XELOS\Modules\Translation
	 */
	class TestPage extends \XELOS\Framework\Module\Page\Page
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
		 * Pages for the GECKO registration process.
		 *
		 * @package XELOS\Modules\Translation
		 */
		public function page_overview(){}

		/**
		 * Pages for the GECKO registration process.
		 *
		 * @package XELOS\Modules\Translation
		 */
		public function page_tokens(){}

	}
} 

namespace XELOS\Modules\Translation\Action\Traits{

	trait CommonOperationsTrait
	{

		/** @var array Maps target language to db language string representation */
		private $lang_strings;

		/** @var \XELOS\Modules\Translation\TranslationController */
		public $mod;



		/**
			 * Builds a map of available system languages in $lang_strings: ['de' => 'DE_DE', 'en' => 'EN_GB', ...]
			 */
		protected function buildLangStrings(){}

		/**
			 * Creates a translation_job model
			 *
			 * @param string $content
			 * @param string $target_model
			 * @param int    $target_id
			 * @param string $language
			 * @param bool   $add_to_search_index
			 * @param int    $priority
			 *
			 * @return \XELOS\Modules\Translation\Model\TranslationJob
			 */
		public function createTranslationJob($content, $target_model, $target_id, $language, $add_to_search_index = true, $priority = 1){}

		/**
			 * @param string $language The language to get the db string for eg.: 'de'
			 *
			 * @return string $db_string The i18n db field representation of lang eg.: 'DE_DE'
			 * @throws TranslationException If language string could not be mapped
			 */
		public function getDbLanguageString($language){}

		/**
			 * Getter for $lang_strings
			 *
			 * @return array
			 */
		public function getLangStrings(){}

	}
} 

namespace XELOS\Modules\Translation\Hook\Doclink{

	/**
	 * Class TranslateProcessor
	 */
	class TranslateProcessor extends \xm_doclink_processor
	{

		/** @var \XELOS\Modules\Translation\TranslationController */
		public $mod;



		/**
		     * Get action
		     *
		     * @inheritdoc
		     *
		     * @return array
		     */
		public function get_action($id, $document_index = NULL){}

		/**
		 * Class TranslateProcessor
		 */
		public function init(){}

		/**
		     * Process translation
		     *
		     * @param \XELOS\Framework\XF\System\Model\DocumentIndex $document_index
		     * @param mixed         $action_status
		     * @param bool          $direct_show
		     *
		     * @return bool|array|\XELOS\Framework\Core\Template
		     * @throws \Exception
		     */
		public function process_translation(\XELOS\Framework\XF\System\Model\DocumentIndex $document_index, $action_status = false, $direct_show = false){}

		/**
		     * @param string|\XELOS\Framework\Core\Template $content
		     * @param null|int        $document_index_id The document index id
		     * @param bool            $only_cached
		     * @param bool            $force Force the translation
		     *
		     * @return string|array
		     * @throws \Exception
		     */
		public function translate($content, $document_index_id = NULL, $only_cached = false, $force = true){}

	}
} 

namespace XELOS\Modules\Translation\Hook\Search{

	/**
	 * Is triggered when a document_index is created or modified. Check if the translation API has to be called.
	 *
	 * Class IndexEventDocumentIndexEvent
	 */
	class TranslateDocumentSearchPreprocessor extends \XELOS\Framework\Module\Hook\BaseHook implements \XELOS\Modules\Search\Interfaces\SearchPreprocessorInterface
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
			 * Builds a XML string for the relevant searchRecord data to be able to translate the record content
			 * in one single translation job
			 *
			 * @param \XELOS\Modules\Search\SearchIndexContentRecord $record
			 *
			 * @return string $xml The XML string with all search record elements
			 */
		private function buildXMLRecordContent(\XELOS\Modules\Search\SearchIndexContentRecord $record){}

		/**
			 * Extracts the searchRecord content data from the XML
			 *
			 * @param string $condensed The XML string with all search record elements
			 *
			 * @return array The extracted record elements (e.g.: ['title'=>'[...]', 'summary'=>'[...]', [...])
			 */
		private function extractXMLRecordContent($condensed){}

		/**
			 * Determines if the translate search result config option is enabled
			 * @return bool
			 */
		public function isAvailable(){}

		/**
			 * Check for possible translations for the SearchIndexRecord. Create translation jobs, if there are
			 * translations missing
			 *
			 * @param \XELOS\Modules\Search\SearchIndexRecord $searchDocument
			 *
			 * @return \XELOS\Modules\Search\SearchIndexRecord
			 */
		public function preProcessDocument(\XELOS\Modules\Search\SearchIndexRecord $searchDocument){}

	}
} 

namespace XELOS\Modules\Translation\Hook\System{

	/**
	 * Is triggered when a document_index is created or modified. Check if the translation API has to be called.
	 *
	 * Class IndexEventDocumentIndexEvent
	 */
	class IndexEventDocumentIndexEvent extends \XELOS\Framework\Module\Hook\IndexEventHook implements \XELOS\Framework\Core\Interfaces\IndexEventInterface
	{

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;



		/**
		 * Is triggered when a document_index is created or modified. Check if the translation API has to be called.
		 *
		 * Class IndexEventDocumentIndexEvent
		 */
		public function end_processing(){}

		/**
		 * Is triggered when a document_index is created or modified. Check if the translation API has to be called.
		 *
		 * Class IndexEventDocumentIndexEvent
		 */
		public function prepare_processing(){}

		/**
			 * @param \XELOS\Framework\XF\System\Model\DocumentIndex $documentIndex
			 * @param string        $event
			 * @param int           $eventUserId
			 *
			 * @return void
			 * @throws \Exception
			 */
		public function process_document_index($documentIndex, $event, $eventUserId = NULL){}

	}

	/**
	 * Class TranslationInProgressMultiplex
	 */
	class TranslationInProgressFrontendHook extends \XELOS\Framework\Module\Hook\BaseHook implements \XELOS\Framework\XF\System\Hook\FrontendBackgroundUpdateInterface
	{



		/**
			 * Returns true if this hook is available otherwise false.
			 *
			 * @return bool
			 */
		public function isAvailable(){}

		/**
			 * This method returns an array that contains information which will be
			 * processed on client side as json object. The optional first parameter can contain
			 * client side created data which can be used to process the request.
			 *
			 * @param array $data
			 *
			 * @return array
			 * @throws TranslationException|\Exception
			 */
		public function response(array $data){}

	}
} 

namespace XELOS\Modules\Translation\Hook\SystemStatus{

	class ApiCheck extends \XELOS\Modules\SystemStatus\Interfaces\ServiceCheck
	{

		/** @var \XELOS\Modules\Translation\TranslationController */
		public $mod;



		public function __construct(){}

		public function run_check(){}

	}
} 

namespace XELOS\Modules\Translation\Lib\Api{

	/**
	 * Class BaseTranslationApi
	 * @package XELOS\Modules\Translation\Lib\Api
	 */
	abstract class BaseTranslationApi
	{

		/** @var string */
		protected $content;

		/** @var array Tags, which should be ignored in translate process (If API supports this) */
		public $ignoreTags;

		/** @var \XELOS\Modules\Translation\TranslationController $mod */
		public $mod;

		/** @var string */
		protected $source_language;

		/** @var string */
		protected $target_language;

		/** @var string */
		protected $translated_content;

		/** @var string */
		protected $url;



		/**
		     * Checks if all requirements are set for a successfull translation call
		     *
		     * @return array $errors Is an ampty array if there are no errors.
		     */
		protected function checkRequirements(){}

		/**
			 * @param string $apiStatusMessage
			 *
			 * @return bool|null
			 */
		public function getAPIStatus($apiStatusMessage = ''){}

		/**
		     * @return string
		     */
		public function getContent(){}

		/**
		     * @return string
		     */
		public function getSourceLanguage(){}

		/**
		     * @return string
		     */
		public function getTargetLanguage(){}

		/**
		     * @return string
		     */
		public function getTranslatedContent(){}

		/**
		     * @return string
		     */
		public function getUrl(){}

		/**
			 * @return bool This Api has a feedback loop. It is possible to send inproved translations to an endpoint
			 */
		public function hasFeedbackLoop(){}

		/**
			 * Send feedback aka improved human translation to the API
			 *
			 * @param string $text                The source text in the source language
			 * @param string $human               The improved human translation in the target language
			 * @param string $srcLang             The source language string
			 * @param string $tgtLang             The target language string
			 * @param string $originalTranslation The original received auto translation
			 *
			 * @return void
			 * @throws TranslationException On error
			 */
		public function sendFeedback($text, $human, $srcLang, $tgtLang, $originalTranslation){}

		/**
			 * Sets the config var 'translation_enabled' to false to disable automatic translations.
			 * Is triggered for example by a translation character quota bigger than 98%
			 * @return void
			 */
		public function setBackgroundTranslationToDisabled(){}

		/**
		     * @param string $content
		     */
		public function setContent($content){}

		/**
		     * Sets possible content and target language
		     *
		     * @param string $content
		     * @param string $target_language
		     * @return void
		     */
		protected function setParameters($content, $target_language){}

		/**
		     * @param string $source_language
		     */
		public function setSourceLanguage($source_language){}

		/**
		     * @param string $target_language
		     */
		public function setTargetLanguage($target_language){}

		/**
		     * @param string $translated_content
		     */
		public function setTranslatedContent($translated_content){}

		/**
		     * @param string $url
		     */
		public function setUrl($url){}

		/**
		     * Translates content to target language. Possible errors should be added to the error array.
		     *
		     * @param null|string $content
		     * @param null|string $target_language
		     * @return array $errors Is an empty Array if no errors.
		     * @throws TranslationException
		     */
		abstract public function translate($content = NULL, $target_language = NULL);

	}

	/**
	 * Class Deepl
	 * @see https://www.deepl.com/api.html
	 */
	class Deepl extends \XELOS\Modules\Translation\Lib\Api\BaseTranslationApi
	{

		/** @var string */
		protected $key;

		/** @var string URL for API */
		protected $url;



		/**
			 * DeepL Translate
			 *
			 * @param $target_language
			 * @param $content
			 *
			 * @return mixed|null
			 */
		private function apiTranslate($target_language, $content){}

		/**
			 * @return mixed|null
			 */
		private function apiUsage(){}

		/**
			 * @inheritdoc
			 */
		protected function checkRequirements(){}

		/**
			 * Run DeepL API call
			 *
			 * @param string $url
			 * @param string $method
			 * @param array $data The data array
			 *
			 * @return mixed|null
			 */
		private function doAPICall($url, $method = 'get', $data = array ( )){}

		/**
			 * @param string $apiStatusMessage
			 *
			 * @return bool|null
			 */
		public function getAPIStatus($apiStatusMessage = ''){}

		/**
			 * @return string
			 */
		public function getKey(){}

		/**
			 * Returns the prepared data array for a request
			 *
			 * @return array $data
			 */
		private function getRequestData(){}

		/**
			 * @param string $key
			 */
		public function setKey($key){}

		/**
			 * @inheritdoc
			 * @throws TranslationException if source language is unknown
			 */
		public function setSourceLanguage($source_language){}

		/**
			 * @inheritdoc
			 * @throws TranslationException if source language is unknown
			 */
		public function translate($content = NULL, $target_language = NULL){}

	}

	class Google extends \XELOS\Modules\Translation\Lib\Api\BaseTranslationApi
	{

		/** @var string */
		protected $key;



		/**
		     * @inheritdoc
		     */
		protected function checkRequirements(){}

		/**
		     * @return string
		     */
		public function getKey(){}

		/**
		     * @inheritdoc
		     */
		protected function getTranslation($url){}

		/**
		     * @param string $key
		     */
		public function setKey($key){}

		/**
		     * @inheritdoc
		     */
		public function translate($content = NULL, $target_language = NULL){}

	}

	class Transperfect extends \XELOS\Modules\Translation\Lib\Api\BaseTranslationApi
	{

		/** @var string */
		protected $key;



		/**
			 * @inheritdoc
			 */
		protected function checkRequirements(){}

		/**
			 * @return string
			 */
		public function getKey(){}

		/**
			 * Queries API and returns result data array
			 *
			 * @return array|null $data The translation result data
			 * @throws TranslationException
			 */
		protected function getTranslation(){}

		/**
			 * Trims the url provided by config value and also removes a trailing slash if present.
			 *
			 * @return string the url
			 */
		public function getUrl(){}

		/**
			 * @inheritdoc
			 */
		public function hasFeedbackLoop(){}

		/**
			 * @inheritdoc
			 */
		public function sendFeedback($text, $human, $srcLang, $tgtLang, $originalTranslation){}

		/**
			 * Returns the response from the endpoint. Form post.
			 *
			 * @param string $url The endpoint url
			 * @param array $headers The headers as ['headerName' => 'value']
			 * @param array $body The Form values ['source'=>'de', ...]
			 *
			 * @return \Httpful\Response
			 * @throws \Httpful\Exception\ConnectionErrorException
			 */
		protected function sendFormRequest($url, $headers, $body){}

		/**
			 * @param string $key
			 */
		public function setKey($key){}

		/**
			 * @inheritdoc
			 * @throws TranslationException if source language is unknown
			 */
		public function setSourceLanguage($source_language){}

		/**
			 * @inheritdoc
			 */
		public function translate($content = NULL, $target_language = NULL){}

	}
} 

namespace XELOS\Modules\Translation\Model\Traits{

	trait CommonOperationsTrait
	{

		 
		public static $TRANSLATED_CONTENT_PROPERTY_START = 'content_';



		/**
		     * Deletes model and also deletes possible related translation_job models
		     *
		     * @return bool Was delete successful?
		     */
		public function delete(){}

		/**
			 * Returns the content for the given $locale... if there is any
			 * @param string $locale The locale (e.g. 'DE_DE', 'EN_GB', ...)
			 *
			 * @return null|string $content
			 */
		public function getContentForLocale($locale){}

		/**
		     * Determines which language has not translation yet
		     *
		     * @return array $missing The locale strings with empty content
		     */
		public function getMissingTranslations(){}

		/**
		     * Returns the $original_language content if possible
		     *
		     * @return null|string $content
		     */
		public function getOriginalContent(){}

		/**
			 * @return array $translatedContent E.g.: ['DE_DE'=>[...], 'EN_GB' => [...]]
			 */
		public function getTranslatedContent(){}

		/**
		     * Resets/Emptys all content related to the translation
		     *
		     * @return void
		     */
		public function resetContent(){}

	}
} 

