<?php

/**
 * This script uses the class alias map to create a look up file for
 * phpdoc auto completion. Execute this script over cli to rebuild the
 * alias lookup file.
 */

$map = require '../../class/_class_alias_map.php';

$content = "<?php /** @noinspection ALL\n*Fake classes for IDE only\n*/ \n";
foreach( $map as $class => $possible_aliases){

	$global_ns_class = $class;
	if($global_ns_class{0} !== '\\'){//Absolute Namespace please
		$global_ns_class = '\\'.$global_ns_class;
	}

	foreach( $possible_aliases as $alias ){
		if(0 === strcasecmp($class,$alias)){
			continue;
		} // PHP is case insensitive for the class naming, we skip entries mapping to itself

		$type = 'class';
		$namespace = '';
		if($ns_pos = strrpos($alias,'\\')) { //Namespaced
			$namespace = substr($alias, 0, $ns_pos).' ';
			$alias = substr($alias, $ns_pos + 1);
		}
		if(strstr($class,'Interface')){
			$type = 'interface';
		}
		if(strstr($class,'Trait')){
			$type = 'trait';
		}
		if($class === 'is_abstract'){//We cannot detect abstract Classes, you need to do this manually after generating the file :)
			$type = 'abstract class';
		}

		$content .= "namespace {$namespace}{\n";
		$content .= "\t/** @deprecated for {$global_ns_class} */\n";
		if($type === 'trait'){//Trait cannot extend another class.. @mixin is handled like a trait
			$content .= "\n/** @mixin {$global_ns_class} */\n";
			$content .= "\t{$type} {$alias} {}\n";
		}else {
			$content .= "\t{$type} {$alias} extends {$global_ns_class} {}\n";
		}
		$content .= "}\n\n";
	}
}
file_put_contents('../class_alias_lookup.php', $content);